# -*- coding: utf-8 -*-

from stripe.v2.core._event import (
    UnknownEventNotification as UnknownEventNotification,
)

# The beginning of the section generated from our OpenAPI spec
from stripe.events._event_classes import (
    ALL_EVENT_NOTIFICATIONS as ALL_EVENT_NOTIFICATIONS,
)
from stripe.events._v1_account_updated_event import (
    V1AccountUpdatedEvent as V1AccountUpdatedEvent,
    V1AccountUpdatedEventNotification as V1AccountUpdatedEventNotification,
)
from stripe.events._v1_application_fee_created_event import (
    V1ApplicationFeeCreatedEvent as V1ApplicationFeeCreatedEvent,
    V1ApplicationFeeCreatedEventNotification as V1ApplicationFeeCreatedEventNotification,
)
from stripe.events._v1_application_fee_refunded_event import (
    V1ApplicationFeeRefundedEvent as V1ApplicationFeeRefundedEvent,
    V1ApplicationFeeRefundedEventNotification as V1ApplicationFeeRefundedEventNotification,
)
from stripe.events._v1_billing_meter_error_report_triggered_event import (
    V1BillingMeterErrorReportTriggeredEvent as V1BillingMeterErrorReportTriggeredEvent,
    V1BillingMeterErrorReportTriggeredEventNotification as V1BillingMeterErrorReportTriggeredEventNotification,
)
from stripe.events._v1_billing_meter_no_meter_found_event import (
    V1BillingMeterNoMeterFoundEvent as V1BillingMeterNoMeterFoundEvent,
    V1BillingMeterNoMeterFoundEventNotification as V1BillingMeterNoMeterFoundEventNotification,
)
from stripe.events._v1_billing_portal_configuration_created_event import (
    V1BillingPortalConfigurationCreatedEvent as V1BillingPortalConfigurationCreatedEvent,
    V1BillingPortalConfigurationCreatedEventNotification as V1BillingPortalConfigurationCreatedEventNotification,
)
from stripe.events._v1_billing_portal_configuration_updated_event import (
    V1BillingPortalConfigurationUpdatedEvent as V1BillingPortalConfigurationUpdatedEvent,
    V1BillingPortalConfigurationUpdatedEventNotification as V1BillingPortalConfigurationUpdatedEventNotification,
)
from stripe.events._v1_capability_updated_event import (
    V1CapabilityUpdatedEvent as V1CapabilityUpdatedEvent,
    V1CapabilityUpdatedEventNotification as V1CapabilityUpdatedEventNotification,
)
from stripe.events._v1_charge_captured_event import (
    V1ChargeCapturedEvent as V1ChargeCapturedEvent,
    V1ChargeCapturedEventNotification as V1ChargeCapturedEventNotification,
)
from stripe.events._v1_charge_dispute_closed_event import (
    V1ChargeDisputeClosedEvent as V1ChargeDisputeClosedEvent,
    V1ChargeDisputeClosedEventNotification as V1ChargeDisputeClosedEventNotification,
)
from stripe.events._v1_charge_dispute_created_event import (
    V1ChargeDisputeCreatedEvent as V1ChargeDisputeCreatedEvent,
    V1ChargeDisputeCreatedEventNotification as V1ChargeDisputeCreatedEventNotification,
)
from stripe.events._v1_charge_dispute_funds_reinstated_event import (
    V1ChargeDisputeFundsReinstatedEvent as V1ChargeDisputeFundsReinstatedEvent,
    V1ChargeDisputeFundsReinstatedEventNotification as V1ChargeDisputeFundsReinstatedEventNotification,
)
from stripe.events._v1_charge_dispute_funds_withdrawn_event import (
    V1ChargeDisputeFundsWithdrawnEvent as V1ChargeDisputeFundsWithdrawnEvent,
    V1ChargeDisputeFundsWithdrawnEventNotification as V1ChargeDisputeFundsWithdrawnEventNotification,
)
from stripe.events._v1_charge_dispute_updated_event import (
    V1ChargeDisputeUpdatedEvent as V1ChargeDisputeUpdatedEvent,
    V1ChargeDisputeUpdatedEventNotification as V1ChargeDisputeUpdatedEventNotification,
)
from stripe.events._v1_charge_expired_event import (
    V1ChargeExpiredEvent as V1ChargeExpiredEvent,
    V1ChargeExpiredEventNotification as V1ChargeExpiredEventNotification,
)
from stripe.events._v1_charge_failed_event import (
    V1ChargeFailedEvent as V1ChargeFailedEvent,
    V1ChargeFailedEventNotification as V1ChargeFailedEventNotification,
)
from stripe.events._v1_charge_pending_event import (
    V1ChargePendingEvent as V1ChargePendingEvent,
    V1ChargePendingEventNotification as V1ChargePendingEventNotification,
)
from stripe.events._v1_charge_refund_updated_event import (
    V1ChargeRefundUpdatedEvent as V1ChargeRefundUpdatedEvent,
    V1ChargeRefundUpdatedEventNotification as V1ChargeRefundUpdatedEventNotification,
)
from stripe.events._v1_charge_refunded_event import (
    V1ChargeRefundedEvent as V1ChargeRefundedEvent,
    V1ChargeRefundedEventNotification as V1ChargeRefundedEventNotification,
)
from stripe.events._v1_charge_succeeded_event import (
    V1ChargeSucceededEvent as V1ChargeSucceededEvent,
    V1ChargeSucceededEventNotification as V1ChargeSucceededEventNotification,
)
from stripe.events._v1_charge_updated_event import (
    V1ChargeUpdatedEvent as V1ChargeUpdatedEvent,
    V1ChargeUpdatedEventNotification as V1ChargeUpdatedEventNotification,
)
from stripe.events._v1_checkout_session_async_payment_failed_event import (
    V1CheckoutSessionAsyncPaymentFailedEvent as V1CheckoutSessionAsyncPaymentFailedEvent,
    V1CheckoutSessionAsyncPaymentFailedEventNotification as V1CheckoutSessionAsyncPaymentFailedEventNotification,
)
from stripe.events._v1_checkout_session_async_payment_succeeded_event import (
    V1CheckoutSessionAsyncPaymentSucceededEvent as V1CheckoutSessionAsyncPaymentSucceededEvent,
    V1CheckoutSessionAsyncPaymentSucceededEventNotification as V1CheckoutSessionAsyncPaymentSucceededEventNotification,
)
from stripe.events._v1_checkout_session_completed_event import (
    V1CheckoutSessionCompletedEvent as V1CheckoutSessionCompletedEvent,
    V1CheckoutSessionCompletedEventNotification as V1CheckoutSessionCompletedEventNotification,
)
from stripe.events._v1_checkout_session_expired_event import (
    V1CheckoutSessionExpiredEvent as V1CheckoutSessionExpiredEvent,
    V1CheckoutSessionExpiredEventNotification as V1CheckoutSessionExpiredEventNotification,
)
from stripe.events._v1_climate_order_canceled_event import (
    V1ClimateOrderCanceledEvent as V1ClimateOrderCanceledEvent,
    V1ClimateOrderCanceledEventNotification as V1ClimateOrderCanceledEventNotification,
)
from stripe.events._v1_climate_order_created_event import (
    V1ClimateOrderCreatedEvent as V1ClimateOrderCreatedEvent,
    V1ClimateOrderCreatedEventNotification as V1ClimateOrderCreatedEventNotification,
)
from stripe.events._v1_climate_order_delayed_event import (
    V1ClimateOrderDelayedEvent as V1ClimateOrderDelayedEvent,
    V1ClimateOrderDelayedEventNotification as V1ClimateOrderDelayedEventNotification,
)
from stripe.events._v1_climate_order_delivered_event import (
    V1ClimateOrderDeliveredEvent as V1ClimateOrderDeliveredEvent,
    V1ClimateOrderDeliveredEventNotification as V1ClimateOrderDeliveredEventNotification,
)
from stripe.events._v1_climate_order_product_substituted_event import (
    V1ClimateOrderProductSubstitutedEvent as V1ClimateOrderProductSubstitutedEvent,
    V1ClimateOrderProductSubstitutedEventNotification as V1ClimateOrderProductSubstitutedEventNotification,
)
from stripe.events._v1_climate_product_created_event import (
    V1ClimateProductCreatedEvent as V1ClimateProductCreatedEvent,
    V1ClimateProductCreatedEventNotification as V1ClimateProductCreatedEventNotification,
)
from stripe.events._v1_climate_product_pricing_updated_event import (
    V1ClimateProductPricingUpdatedEvent as V1ClimateProductPricingUpdatedEvent,
    V1ClimateProductPricingUpdatedEventNotification as V1ClimateProductPricingUpdatedEventNotification,
)
from stripe.events._v1_coupon_created_event import (
    V1CouponCreatedEvent as V1CouponCreatedEvent,
    V1CouponCreatedEventNotification as V1CouponCreatedEventNotification,
)
from stripe.events._v1_coupon_deleted_event import (
    V1CouponDeletedEvent as V1CouponDeletedEvent,
    V1CouponDeletedEventNotification as V1CouponDeletedEventNotification,
)
from stripe.events._v1_coupon_updated_event import (
    V1CouponUpdatedEvent as V1CouponUpdatedEvent,
    V1CouponUpdatedEventNotification as V1CouponUpdatedEventNotification,
)
from stripe.events._v1_credit_note_created_event import (
    V1CreditNoteCreatedEvent as V1CreditNoteCreatedEvent,
    V1CreditNoteCreatedEventNotification as V1CreditNoteCreatedEventNotification,
)
from stripe.events._v1_credit_note_updated_event import (
    V1CreditNoteUpdatedEvent as V1CreditNoteUpdatedEvent,
    V1CreditNoteUpdatedEventNotification as V1CreditNoteUpdatedEventNotification,
)
from stripe.events._v1_credit_note_voided_event import (
    V1CreditNoteVoidedEvent as V1CreditNoteVoidedEvent,
    V1CreditNoteVoidedEventNotification as V1CreditNoteVoidedEventNotification,
)
from stripe.events._v1_customer_created_event import (
    V1CustomerCreatedEvent as V1CustomerCreatedEvent,
    V1CustomerCreatedEventNotification as V1CustomerCreatedEventNotification,
)
from stripe.events._v1_customer_deleted_event import (
    V1CustomerDeletedEvent as V1CustomerDeletedEvent,
    V1CustomerDeletedEventNotification as V1CustomerDeletedEventNotification,
)
from stripe.events._v1_customer_subscription_created_event import (
    V1CustomerSubscriptionCreatedEvent as V1CustomerSubscriptionCreatedEvent,
    V1CustomerSubscriptionCreatedEventNotification as V1CustomerSubscriptionCreatedEventNotification,
)
from stripe.events._v1_customer_subscription_deleted_event import (
    V1CustomerSubscriptionDeletedEvent as V1CustomerSubscriptionDeletedEvent,
    V1CustomerSubscriptionDeletedEventNotification as V1CustomerSubscriptionDeletedEventNotification,
)
from stripe.events._v1_customer_subscription_paused_event import (
    V1CustomerSubscriptionPausedEvent as V1CustomerSubscriptionPausedEvent,
    V1CustomerSubscriptionPausedEventNotification as V1CustomerSubscriptionPausedEventNotification,
)
from stripe.events._v1_customer_subscription_pending_update_applied_event import (
    V1CustomerSubscriptionPendingUpdateAppliedEvent as V1CustomerSubscriptionPendingUpdateAppliedEvent,
    V1CustomerSubscriptionPendingUpdateAppliedEventNotification as V1CustomerSubscriptionPendingUpdateAppliedEventNotification,
)
from stripe.events._v1_customer_subscription_pending_update_expired_event import (
    V1CustomerSubscriptionPendingUpdateExpiredEvent as V1CustomerSubscriptionPendingUpdateExpiredEvent,
    V1CustomerSubscriptionPendingUpdateExpiredEventNotification as V1CustomerSubscriptionPendingUpdateExpiredEventNotification,
)
from stripe.events._v1_customer_subscription_resumed_event import (
    V1CustomerSubscriptionResumedEvent as V1CustomerSubscriptionResumedEvent,
    V1CustomerSubscriptionResumedEventNotification as V1CustomerSubscriptionResumedEventNotification,
)
from stripe.events._v1_customer_subscription_trial_will_end_event import (
    V1CustomerSubscriptionTrialWillEndEvent as V1CustomerSubscriptionTrialWillEndEvent,
    V1CustomerSubscriptionTrialWillEndEventNotification as V1CustomerSubscriptionTrialWillEndEventNotification,
)
from stripe.events._v1_customer_subscription_updated_event import (
    V1CustomerSubscriptionUpdatedEvent as V1CustomerSubscriptionUpdatedEvent,
    V1CustomerSubscriptionUpdatedEventNotification as V1CustomerSubscriptionUpdatedEventNotification,
)
from stripe.events._v1_customer_tax_id_created_event import (
    V1CustomerTaxIdCreatedEvent as V1CustomerTaxIdCreatedEvent,
    V1CustomerTaxIdCreatedEventNotification as V1CustomerTaxIdCreatedEventNotification,
)
from stripe.events._v1_customer_tax_id_deleted_event import (
    V1CustomerTaxIdDeletedEvent as V1CustomerTaxIdDeletedEvent,
    V1CustomerTaxIdDeletedEventNotification as V1CustomerTaxIdDeletedEventNotification,
)
from stripe.events._v1_customer_tax_id_updated_event import (
    V1CustomerTaxIdUpdatedEvent as V1CustomerTaxIdUpdatedEvent,
    V1CustomerTaxIdUpdatedEventNotification as V1CustomerTaxIdUpdatedEventNotification,
)
from stripe.events._v1_customer_updated_event import (
    V1CustomerUpdatedEvent as V1CustomerUpdatedEvent,
    V1CustomerUpdatedEventNotification as V1CustomerUpdatedEventNotification,
)
from stripe.events._v1_file_created_event import (
    V1FileCreatedEvent as V1FileCreatedEvent,
    V1FileCreatedEventNotification as V1FileCreatedEventNotification,
)
from stripe.events._v1_financial_connections_account_created_event import (
    V1FinancialConnectionsAccountCreatedEvent as V1FinancialConnectionsAccountCreatedEvent,
    V1FinancialConnectionsAccountCreatedEventNotification as V1FinancialConnectionsAccountCreatedEventNotification,
)
from stripe.events._v1_financial_connections_account_deactivated_event import (
    V1FinancialConnectionsAccountDeactivatedEvent as V1FinancialConnectionsAccountDeactivatedEvent,
    V1FinancialConnectionsAccountDeactivatedEventNotification as V1FinancialConnectionsAccountDeactivatedEventNotification,
)
from stripe.events._v1_financial_connections_account_disconnected_event import (
    V1FinancialConnectionsAccountDisconnectedEvent as V1FinancialConnectionsAccountDisconnectedEvent,
    V1FinancialConnectionsAccountDisconnectedEventNotification as V1FinancialConnectionsAccountDisconnectedEventNotification,
)
from stripe.events._v1_financial_connections_account_reactivated_event import (
    V1FinancialConnectionsAccountReactivatedEvent as V1FinancialConnectionsAccountReactivatedEvent,
    V1FinancialConnectionsAccountReactivatedEventNotification as V1FinancialConnectionsAccountReactivatedEventNotification,
)
from stripe.events._v1_financial_connections_account_refreshed_balance_event import (
    V1FinancialConnectionsAccountRefreshedBalanceEvent as V1FinancialConnectionsAccountRefreshedBalanceEvent,
    V1FinancialConnectionsAccountRefreshedBalanceEventNotification as V1FinancialConnectionsAccountRefreshedBalanceEventNotification,
)
from stripe.events._v1_financial_connections_account_refreshed_ownership_event import (
    V1FinancialConnectionsAccountRefreshedOwnershipEvent as V1FinancialConnectionsAccountRefreshedOwnershipEvent,
    V1FinancialConnectionsAccountRefreshedOwnershipEventNotification as V1FinancialConnectionsAccountRefreshedOwnershipEventNotification,
)
from stripe.events._v1_financial_connections_account_refreshed_transactions_event import (
    V1FinancialConnectionsAccountRefreshedTransactionsEvent as V1FinancialConnectionsAccountRefreshedTransactionsEvent,
    V1FinancialConnectionsAccountRefreshedTransactionsEventNotification as V1FinancialConnectionsAccountRefreshedTransactionsEventNotification,
)
from stripe.events._v1_identity_verification_session_canceled_event import (
    V1IdentityVerificationSessionCanceledEvent as V1IdentityVerificationSessionCanceledEvent,
    V1IdentityVerificationSessionCanceledEventNotification as V1IdentityVerificationSessionCanceledEventNotification,
)
from stripe.events._v1_identity_verification_session_created_event import (
    V1IdentityVerificationSessionCreatedEvent as V1IdentityVerificationSessionCreatedEvent,
    V1IdentityVerificationSessionCreatedEventNotification as V1IdentityVerificationSessionCreatedEventNotification,
)
from stripe.events._v1_identity_verification_session_processing_event import (
    V1IdentityVerificationSessionProcessingEvent as V1IdentityVerificationSessionProcessingEvent,
    V1IdentityVerificationSessionProcessingEventNotification as V1IdentityVerificationSessionProcessingEventNotification,
)
from stripe.events._v1_identity_verification_session_redacted_event import (
    V1IdentityVerificationSessionRedactedEvent as V1IdentityVerificationSessionRedactedEvent,
    V1IdentityVerificationSessionRedactedEventNotification as V1IdentityVerificationSessionRedactedEventNotification,
)
from stripe.events._v1_identity_verification_session_requires_input_event import (
    V1IdentityVerificationSessionRequiresInputEvent as V1IdentityVerificationSessionRequiresInputEvent,
    V1IdentityVerificationSessionRequiresInputEventNotification as V1IdentityVerificationSessionRequiresInputEventNotification,
)
from stripe.events._v1_identity_verification_session_verified_event import (
    V1IdentityVerificationSessionVerifiedEvent as V1IdentityVerificationSessionVerifiedEvent,
    V1IdentityVerificationSessionVerifiedEventNotification as V1IdentityVerificationSessionVerifiedEventNotification,
)
from stripe.events._v1_invoice_created_event import (
    V1InvoiceCreatedEvent as V1InvoiceCreatedEvent,
    V1InvoiceCreatedEventNotification as V1InvoiceCreatedEventNotification,
)
from stripe.events._v1_invoice_deleted_event import (
    V1InvoiceDeletedEvent as V1InvoiceDeletedEvent,
    V1InvoiceDeletedEventNotification as V1InvoiceDeletedEventNotification,
)
from stripe.events._v1_invoice_finalization_failed_event import (
    V1InvoiceFinalizationFailedEvent as V1InvoiceFinalizationFailedEvent,
    V1InvoiceFinalizationFailedEventNotification as V1InvoiceFinalizationFailedEventNotification,
)
from stripe.events._v1_invoice_finalized_event import (
    V1InvoiceFinalizedEvent as V1InvoiceFinalizedEvent,
    V1InvoiceFinalizedEventNotification as V1InvoiceFinalizedEventNotification,
)
from stripe.events._v1_invoice_marked_uncollectible_event import (
    V1InvoiceMarkedUncollectibleEvent as V1InvoiceMarkedUncollectibleEvent,
    V1InvoiceMarkedUncollectibleEventNotification as V1InvoiceMarkedUncollectibleEventNotification,
)
from stripe.events._v1_invoice_overdue_event import (
    V1InvoiceOverdueEvent as V1InvoiceOverdueEvent,
    V1InvoiceOverdueEventNotification as V1InvoiceOverdueEventNotification,
)
from stripe.events._v1_invoice_overpaid_event import (
    V1InvoiceOverpaidEvent as V1InvoiceOverpaidEvent,
    V1InvoiceOverpaidEventNotification as V1InvoiceOverpaidEventNotification,
)
from stripe.events._v1_invoice_paid_event import (
    V1InvoicePaidEvent as V1InvoicePaidEvent,
    V1InvoicePaidEventNotification as V1InvoicePaidEventNotification,
)
from stripe.events._v1_invoice_payment_action_required_event import (
    V1InvoicePaymentActionRequiredEvent as V1InvoicePaymentActionRequiredEvent,
    V1InvoicePaymentActionRequiredEventNotification as V1InvoicePaymentActionRequiredEventNotification,
)
from stripe.events._v1_invoice_payment_failed_event import (
    V1InvoicePaymentFailedEvent as V1InvoicePaymentFailedEvent,
    V1InvoicePaymentFailedEventNotification as V1InvoicePaymentFailedEventNotification,
)
from stripe.events._v1_invoice_payment_paid_event import (
    V1InvoicePaymentPaidEvent as V1InvoicePaymentPaidEvent,
    V1InvoicePaymentPaidEventNotification as V1InvoicePaymentPaidEventNotification,
)
from stripe.events._v1_invoice_payment_succeeded_event import (
    V1InvoicePaymentSucceededEvent as V1InvoicePaymentSucceededEvent,
    V1InvoicePaymentSucceededEventNotification as V1InvoicePaymentSucceededEventNotification,
)
from stripe.events._v1_invoice_sent_event import (
    V1InvoiceSentEvent as V1InvoiceSentEvent,
    V1InvoiceSentEventNotification as V1InvoiceSentEventNotification,
)
from stripe.events._v1_invoice_upcoming_event import (
    V1InvoiceUpcomingEvent as V1InvoiceUpcomingEvent,
    V1InvoiceUpcomingEventNotification as V1InvoiceUpcomingEventNotification,
)
from stripe.events._v1_invoice_updated_event import (
    V1InvoiceUpdatedEvent as V1InvoiceUpdatedEvent,
    V1InvoiceUpdatedEventNotification as V1InvoiceUpdatedEventNotification,
)
from stripe.events._v1_invoice_voided_event import (
    V1InvoiceVoidedEvent as V1InvoiceVoidedEvent,
    V1InvoiceVoidedEventNotification as V1InvoiceVoidedEventNotification,
)
from stripe.events._v1_invoice_will_be_due_event import (
    V1InvoiceWillBeDueEvent as V1InvoiceWillBeDueEvent,
    V1InvoiceWillBeDueEventNotification as V1InvoiceWillBeDueEventNotification,
)
from stripe.events._v1_invoiceitem_created_event import (
    V1InvoiceitemCreatedEvent as V1InvoiceitemCreatedEvent,
    V1InvoiceitemCreatedEventNotification as V1InvoiceitemCreatedEventNotification,
)
from stripe.events._v1_invoiceitem_deleted_event import (
    V1InvoiceitemDeletedEvent as V1InvoiceitemDeletedEvent,
    V1InvoiceitemDeletedEventNotification as V1InvoiceitemDeletedEventNotification,
)
from stripe.events._v1_issuing_authorization_created_event import (
    V1IssuingAuthorizationCreatedEvent as V1IssuingAuthorizationCreatedEvent,
    V1IssuingAuthorizationCreatedEventNotification as V1IssuingAuthorizationCreatedEventNotification,
)
from stripe.events._v1_issuing_authorization_request_event import (
    V1IssuingAuthorizationRequestEvent as V1IssuingAuthorizationRequestEvent,
    V1IssuingAuthorizationRequestEventNotification as V1IssuingAuthorizationRequestEventNotification,
)
from stripe.events._v1_issuing_authorization_updated_event import (
    V1IssuingAuthorizationUpdatedEvent as V1IssuingAuthorizationUpdatedEvent,
    V1IssuingAuthorizationUpdatedEventNotification as V1IssuingAuthorizationUpdatedEventNotification,
)
from stripe.events._v1_issuing_card_created_event import (
    V1IssuingCardCreatedEvent as V1IssuingCardCreatedEvent,
    V1IssuingCardCreatedEventNotification as V1IssuingCardCreatedEventNotification,
)
from stripe.events._v1_issuing_card_updated_event import (
    V1IssuingCardUpdatedEvent as V1IssuingCardUpdatedEvent,
    V1IssuingCardUpdatedEventNotification as V1IssuingCardUpdatedEventNotification,
)
from stripe.events._v1_issuing_cardholder_created_event import (
    V1IssuingCardholderCreatedEvent as V1IssuingCardholderCreatedEvent,
    V1IssuingCardholderCreatedEventNotification as V1IssuingCardholderCreatedEventNotification,
)
from stripe.events._v1_issuing_cardholder_updated_event import (
    V1IssuingCardholderUpdatedEvent as V1IssuingCardholderUpdatedEvent,
    V1IssuingCardholderUpdatedEventNotification as V1IssuingCardholderUpdatedEventNotification,
)
from stripe.events._v1_issuing_dispute_closed_event import (
    V1IssuingDisputeClosedEvent as V1IssuingDisputeClosedEvent,
    V1IssuingDisputeClosedEventNotification as V1IssuingDisputeClosedEventNotification,
)
from stripe.events._v1_issuing_dispute_created_event import (
    V1IssuingDisputeCreatedEvent as V1IssuingDisputeCreatedEvent,
    V1IssuingDisputeCreatedEventNotification as V1IssuingDisputeCreatedEventNotification,
)
from stripe.events._v1_issuing_dispute_funds_reinstated_event import (
    V1IssuingDisputeFundsReinstatedEvent as V1IssuingDisputeFundsReinstatedEvent,
    V1IssuingDisputeFundsReinstatedEventNotification as V1IssuingDisputeFundsReinstatedEventNotification,
)
from stripe.events._v1_issuing_dispute_funds_rescinded_event import (
    V1IssuingDisputeFundsRescindedEvent as V1IssuingDisputeFundsRescindedEvent,
    V1IssuingDisputeFundsRescindedEventNotification as V1IssuingDisputeFundsRescindedEventNotification,
)
from stripe.events._v1_issuing_dispute_submitted_event import (
    V1IssuingDisputeSubmittedEvent as V1IssuingDisputeSubmittedEvent,
    V1IssuingDisputeSubmittedEventNotification as V1IssuingDisputeSubmittedEventNotification,
)
from stripe.events._v1_issuing_dispute_updated_event import (
    V1IssuingDisputeUpdatedEvent as V1IssuingDisputeUpdatedEvent,
    V1IssuingDisputeUpdatedEventNotification as V1IssuingDisputeUpdatedEventNotification,
)
from stripe.events._v1_issuing_personalization_design_activated_event import (
    V1IssuingPersonalizationDesignActivatedEvent as V1IssuingPersonalizationDesignActivatedEvent,
    V1IssuingPersonalizationDesignActivatedEventNotification as V1IssuingPersonalizationDesignActivatedEventNotification,
)
from stripe.events._v1_issuing_personalization_design_deactivated_event import (
    V1IssuingPersonalizationDesignDeactivatedEvent as V1IssuingPersonalizationDesignDeactivatedEvent,
    V1IssuingPersonalizationDesignDeactivatedEventNotification as V1IssuingPersonalizationDesignDeactivatedEventNotification,
)
from stripe.events._v1_issuing_personalization_design_rejected_event import (
    V1IssuingPersonalizationDesignRejectedEvent as V1IssuingPersonalizationDesignRejectedEvent,
    V1IssuingPersonalizationDesignRejectedEventNotification as V1IssuingPersonalizationDesignRejectedEventNotification,
)
from stripe.events._v1_issuing_personalization_design_updated_event import (
    V1IssuingPersonalizationDesignUpdatedEvent as V1IssuingPersonalizationDesignUpdatedEvent,
    V1IssuingPersonalizationDesignUpdatedEventNotification as V1IssuingPersonalizationDesignUpdatedEventNotification,
)
from stripe.events._v1_issuing_token_created_event import (
    V1IssuingTokenCreatedEvent as V1IssuingTokenCreatedEvent,
    V1IssuingTokenCreatedEventNotification as V1IssuingTokenCreatedEventNotification,
)
from stripe.events._v1_issuing_token_updated_event import (
    V1IssuingTokenUpdatedEvent as V1IssuingTokenUpdatedEvent,
    V1IssuingTokenUpdatedEventNotification as V1IssuingTokenUpdatedEventNotification,
)
from stripe.events._v1_issuing_transaction_created_event import (
    V1IssuingTransactionCreatedEvent as V1IssuingTransactionCreatedEvent,
    V1IssuingTransactionCreatedEventNotification as V1IssuingTransactionCreatedEventNotification,
)
from stripe.events._v1_issuing_transaction_purchase_details_receipt_updated_event import (
    V1IssuingTransactionPurchaseDetailsReceiptUpdatedEvent as V1IssuingTransactionPurchaseDetailsReceiptUpdatedEvent,
    V1IssuingTransactionPurchaseDetailsReceiptUpdatedEventNotification as V1IssuingTransactionPurchaseDetailsReceiptUpdatedEventNotification,
)
from stripe.events._v1_issuing_transaction_updated_event import (
    V1IssuingTransactionUpdatedEvent as V1IssuingTransactionUpdatedEvent,
    V1IssuingTransactionUpdatedEventNotification as V1IssuingTransactionUpdatedEventNotification,
)
from stripe.events._v1_mandate_updated_event import (
    V1MandateUpdatedEvent as V1MandateUpdatedEvent,
    V1MandateUpdatedEventNotification as V1MandateUpdatedEventNotification,
)
from stripe.events._v1_payment_intent_amount_capturable_updated_event import (
    V1PaymentIntentAmountCapturableUpdatedEvent as V1PaymentIntentAmountCapturableUpdatedEvent,
    V1PaymentIntentAmountCapturableUpdatedEventNotification as V1PaymentIntentAmountCapturableUpdatedEventNotification,
)
from stripe.events._v1_payment_intent_canceled_event import (
    V1PaymentIntentCanceledEvent as V1PaymentIntentCanceledEvent,
    V1PaymentIntentCanceledEventNotification as V1PaymentIntentCanceledEventNotification,
)
from stripe.events._v1_payment_intent_created_event import (
    V1PaymentIntentCreatedEvent as V1PaymentIntentCreatedEvent,
    V1PaymentIntentCreatedEventNotification as V1PaymentIntentCreatedEventNotification,
)
from stripe.events._v1_payment_intent_partially_funded_event import (
    V1PaymentIntentPartiallyFundedEvent as V1PaymentIntentPartiallyFundedEvent,
    V1PaymentIntentPartiallyFundedEventNotification as V1PaymentIntentPartiallyFundedEventNotification,
)
from stripe.events._v1_payment_intent_payment_failed_event import (
    V1PaymentIntentPaymentFailedEvent as V1PaymentIntentPaymentFailedEvent,
    V1PaymentIntentPaymentFailedEventNotification as V1PaymentIntentPaymentFailedEventNotification,
)
from stripe.events._v1_payment_intent_processing_event import (
    V1PaymentIntentProcessingEvent as V1PaymentIntentProcessingEvent,
    V1PaymentIntentProcessingEventNotification as V1PaymentIntentProcessingEventNotification,
)
from stripe.events._v1_payment_intent_requires_action_event import (
    V1PaymentIntentRequiresActionEvent as V1PaymentIntentRequiresActionEvent,
    V1PaymentIntentRequiresActionEventNotification as V1PaymentIntentRequiresActionEventNotification,
)
from stripe.events._v1_payment_intent_succeeded_event import (
    V1PaymentIntentSucceededEvent as V1PaymentIntentSucceededEvent,
    V1PaymentIntentSucceededEventNotification as V1PaymentIntentSucceededEventNotification,
)
from stripe.events._v1_payment_link_created_event import (
    V1PaymentLinkCreatedEvent as V1PaymentLinkCreatedEvent,
    V1PaymentLinkCreatedEventNotification as V1PaymentLinkCreatedEventNotification,
)
from stripe.events._v1_payment_link_updated_event import (
    V1PaymentLinkUpdatedEvent as V1PaymentLinkUpdatedEvent,
    V1PaymentLinkUpdatedEventNotification as V1PaymentLinkUpdatedEventNotification,
)
from stripe.events._v1_payment_method_attached_event import (
    V1PaymentMethodAttachedEvent as V1PaymentMethodAttachedEvent,
    V1PaymentMethodAttachedEventNotification as V1PaymentMethodAttachedEventNotification,
)
from stripe.events._v1_payment_method_automatically_updated_event import (
    V1PaymentMethodAutomaticallyUpdatedEvent as V1PaymentMethodAutomaticallyUpdatedEvent,
    V1PaymentMethodAutomaticallyUpdatedEventNotification as V1PaymentMethodAutomaticallyUpdatedEventNotification,
)
from stripe.events._v1_payment_method_detached_event import (
    V1PaymentMethodDetachedEvent as V1PaymentMethodDetachedEvent,
    V1PaymentMethodDetachedEventNotification as V1PaymentMethodDetachedEventNotification,
)
from stripe.events._v1_payment_method_updated_event import (
    V1PaymentMethodUpdatedEvent as V1PaymentMethodUpdatedEvent,
    V1PaymentMethodUpdatedEventNotification as V1PaymentMethodUpdatedEventNotification,
)
from stripe.events._v1_payout_canceled_event import (
    V1PayoutCanceledEvent as V1PayoutCanceledEvent,
    V1PayoutCanceledEventNotification as V1PayoutCanceledEventNotification,
)
from stripe.events._v1_payout_created_event import (
    V1PayoutCreatedEvent as V1PayoutCreatedEvent,
    V1PayoutCreatedEventNotification as V1PayoutCreatedEventNotification,
)
from stripe.events._v1_payout_failed_event import (
    V1PayoutFailedEvent as V1PayoutFailedEvent,
    V1PayoutFailedEventNotification as V1PayoutFailedEventNotification,
)
from stripe.events._v1_payout_paid_event import (
    V1PayoutPaidEvent as V1PayoutPaidEvent,
    V1PayoutPaidEventNotification as V1PayoutPaidEventNotification,
)
from stripe.events._v1_payout_reconciliation_completed_event import (
    V1PayoutReconciliationCompletedEvent as V1PayoutReconciliationCompletedEvent,
    V1PayoutReconciliationCompletedEventNotification as V1PayoutReconciliationCompletedEventNotification,
)
from stripe.events._v1_payout_updated_event import (
    V1PayoutUpdatedEvent as V1PayoutUpdatedEvent,
    V1PayoutUpdatedEventNotification as V1PayoutUpdatedEventNotification,
)
from stripe.events._v1_person_created_event import (
    V1PersonCreatedEvent as V1PersonCreatedEvent,
    V1PersonCreatedEventNotification as V1PersonCreatedEventNotification,
)
from stripe.events._v1_person_deleted_event import (
    V1PersonDeletedEvent as V1PersonDeletedEvent,
    V1PersonDeletedEventNotification as V1PersonDeletedEventNotification,
)
from stripe.events._v1_person_updated_event import (
    V1PersonUpdatedEvent as V1PersonUpdatedEvent,
    V1PersonUpdatedEventNotification as V1PersonUpdatedEventNotification,
)
from stripe.events._v1_plan_created_event import (
    V1PlanCreatedEvent as V1PlanCreatedEvent,
    V1PlanCreatedEventNotification as V1PlanCreatedEventNotification,
)
from stripe.events._v1_plan_deleted_event import (
    V1PlanDeletedEvent as V1PlanDeletedEvent,
    V1PlanDeletedEventNotification as V1PlanDeletedEventNotification,
)
from stripe.events._v1_plan_updated_event import (
    V1PlanUpdatedEvent as V1PlanUpdatedEvent,
    V1PlanUpdatedEventNotification as V1PlanUpdatedEventNotification,
)
from stripe.events._v1_price_created_event import (
    V1PriceCreatedEvent as V1PriceCreatedEvent,
    V1PriceCreatedEventNotification as V1PriceCreatedEventNotification,
)
from stripe.events._v1_price_deleted_event import (
    V1PriceDeletedEvent as V1PriceDeletedEvent,
    V1PriceDeletedEventNotification as V1PriceDeletedEventNotification,
)
from stripe.events._v1_price_updated_event import (
    V1PriceUpdatedEvent as V1PriceUpdatedEvent,
    V1PriceUpdatedEventNotification as V1PriceUpdatedEventNotification,
)
from stripe.events._v1_product_created_event import (
    V1ProductCreatedEvent as V1ProductCreatedEvent,
    V1ProductCreatedEventNotification as V1ProductCreatedEventNotification,
)
from stripe.events._v1_product_deleted_event import (
    V1ProductDeletedEvent as V1ProductDeletedEvent,
    V1ProductDeletedEventNotification as V1ProductDeletedEventNotification,
)
from stripe.events._v1_product_updated_event import (
    V1ProductUpdatedEvent as V1ProductUpdatedEvent,
    V1ProductUpdatedEventNotification as V1ProductUpdatedEventNotification,
)
from stripe.events._v1_promotion_code_created_event import (
    V1PromotionCodeCreatedEvent as V1PromotionCodeCreatedEvent,
    V1PromotionCodeCreatedEventNotification as V1PromotionCodeCreatedEventNotification,
)
from stripe.events._v1_promotion_code_updated_event import (
    V1PromotionCodeUpdatedEvent as V1PromotionCodeUpdatedEvent,
    V1PromotionCodeUpdatedEventNotification as V1PromotionCodeUpdatedEventNotification,
)
from stripe.events._v1_quote_accepted_event import (
    V1QuoteAcceptedEvent as V1QuoteAcceptedEvent,
    V1QuoteAcceptedEventNotification as V1QuoteAcceptedEventNotification,
)
from stripe.events._v1_quote_canceled_event import (
    V1QuoteCanceledEvent as V1QuoteCanceledEvent,
    V1QuoteCanceledEventNotification as V1QuoteCanceledEventNotification,
)
from stripe.events._v1_quote_created_event import (
    V1QuoteCreatedEvent as V1QuoteCreatedEvent,
    V1QuoteCreatedEventNotification as V1QuoteCreatedEventNotification,
)
from stripe.events._v1_quote_finalized_event import (
    V1QuoteFinalizedEvent as V1QuoteFinalizedEvent,
    V1QuoteFinalizedEventNotification as V1QuoteFinalizedEventNotification,
)
from stripe.events._v1_radar_early_fraud_warning_created_event import (
    V1RadarEarlyFraudWarningCreatedEvent as V1RadarEarlyFraudWarningCreatedEvent,
    V1RadarEarlyFraudWarningCreatedEventNotification as V1RadarEarlyFraudWarningCreatedEventNotification,
)
from stripe.events._v1_radar_early_fraud_warning_updated_event import (
    V1RadarEarlyFraudWarningUpdatedEvent as V1RadarEarlyFraudWarningUpdatedEvent,
    V1RadarEarlyFraudWarningUpdatedEventNotification as V1RadarEarlyFraudWarningUpdatedEventNotification,
)
from stripe.events._v1_refund_created_event import (
    V1RefundCreatedEvent as V1RefundCreatedEvent,
    V1RefundCreatedEventNotification as V1RefundCreatedEventNotification,
)
from stripe.events._v1_refund_failed_event import (
    V1RefundFailedEvent as V1RefundFailedEvent,
    V1RefundFailedEventNotification as V1RefundFailedEventNotification,
)
from stripe.events._v1_refund_updated_event import (
    V1RefundUpdatedEvent as V1RefundUpdatedEvent,
    V1RefundUpdatedEventNotification as V1RefundUpdatedEventNotification,
)
from stripe.events._v1_review_closed_event import (
    V1ReviewClosedEvent as V1ReviewClosedEvent,
    V1ReviewClosedEventNotification as V1ReviewClosedEventNotification,
)
from stripe.events._v1_review_opened_event import (
    V1ReviewOpenedEvent as V1ReviewOpenedEvent,
    V1ReviewOpenedEventNotification as V1ReviewOpenedEventNotification,
)
from stripe.events._v1_setup_intent_canceled_event import (
    V1SetupIntentCanceledEvent as V1SetupIntentCanceledEvent,
    V1SetupIntentCanceledEventNotification as V1SetupIntentCanceledEventNotification,
)
from stripe.events._v1_setup_intent_created_event import (
    V1SetupIntentCreatedEvent as V1SetupIntentCreatedEvent,
    V1SetupIntentCreatedEventNotification as V1SetupIntentCreatedEventNotification,
)
from stripe.events._v1_setup_intent_requires_action_event import (
    V1SetupIntentRequiresActionEvent as V1SetupIntentRequiresActionEvent,
    V1SetupIntentRequiresActionEventNotification as V1SetupIntentRequiresActionEventNotification,
)
from stripe.events._v1_setup_intent_setup_failed_event import (
    V1SetupIntentSetupFailedEvent as V1SetupIntentSetupFailedEvent,
    V1SetupIntentSetupFailedEventNotification as V1SetupIntentSetupFailedEventNotification,
)
from stripe.events._v1_setup_intent_succeeded_event import (
    V1SetupIntentSucceededEvent as V1SetupIntentSucceededEvent,
    V1SetupIntentSucceededEventNotification as V1SetupIntentSucceededEventNotification,
)
from stripe.events._v1_sigma_scheduled_query_run_created_event import (
    V1SigmaScheduledQueryRunCreatedEvent as V1SigmaScheduledQueryRunCreatedEvent,
    V1SigmaScheduledQueryRunCreatedEventNotification as V1SigmaScheduledQueryRunCreatedEventNotification,
)
from stripe.events._v1_source_canceled_event import (
    V1SourceCanceledEvent as V1SourceCanceledEvent,
    V1SourceCanceledEventNotification as V1SourceCanceledEventNotification,
)
from stripe.events._v1_source_chargeable_event import (
    V1SourceChargeableEvent as V1SourceChargeableEvent,
    V1SourceChargeableEventNotification as V1SourceChargeableEventNotification,
)
from stripe.events._v1_source_failed_event import (
    V1SourceFailedEvent as V1SourceFailedEvent,
    V1SourceFailedEventNotification as V1SourceFailedEventNotification,
)
from stripe.events._v1_source_refund_attributes_required_event import (
    V1SourceRefundAttributesRequiredEvent as V1SourceRefundAttributesRequiredEvent,
    V1SourceRefundAttributesRequiredEventNotification as V1SourceRefundAttributesRequiredEventNotification,
)
from stripe.events._v1_subscription_schedule_aborted_event import (
    V1SubscriptionScheduleAbortedEvent as V1SubscriptionScheduleAbortedEvent,
    V1SubscriptionScheduleAbortedEventNotification as V1SubscriptionScheduleAbortedEventNotification,
)
from stripe.events._v1_subscription_schedule_canceled_event import (
    V1SubscriptionScheduleCanceledEvent as V1SubscriptionScheduleCanceledEvent,
    V1SubscriptionScheduleCanceledEventNotification as V1SubscriptionScheduleCanceledEventNotification,
)
from stripe.events._v1_subscription_schedule_completed_event import (
    V1SubscriptionScheduleCompletedEvent as V1SubscriptionScheduleCompletedEvent,
    V1SubscriptionScheduleCompletedEventNotification as V1SubscriptionScheduleCompletedEventNotification,
)
from stripe.events._v1_subscription_schedule_created_event import (
    V1SubscriptionScheduleCreatedEvent as V1SubscriptionScheduleCreatedEvent,
    V1SubscriptionScheduleCreatedEventNotification as V1SubscriptionScheduleCreatedEventNotification,
)
from stripe.events._v1_subscription_schedule_expiring_event import (
    V1SubscriptionScheduleExpiringEvent as V1SubscriptionScheduleExpiringEvent,
    V1SubscriptionScheduleExpiringEventNotification as V1SubscriptionScheduleExpiringEventNotification,
)
from stripe.events._v1_subscription_schedule_released_event import (
    V1SubscriptionScheduleReleasedEvent as V1SubscriptionScheduleReleasedEvent,
    V1SubscriptionScheduleReleasedEventNotification as V1SubscriptionScheduleReleasedEventNotification,
)
from stripe.events._v1_subscription_schedule_updated_event import (
    V1SubscriptionScheduleUpdatedEvent as V1SubscriptionScheduleUpdatedEvent,
    V1SubscriptionScheduleUpdatedEventNotification as V1SubscriptionScheduleUpdatedEventNotification,
)
from stripe.events._v1_tax_rate_created_event import (
    V1TaxRateCreatedEvent as V1TaxRateCreatedEvent,
    V1TaxRateCreatedEventNotification as V1TaxRateCreatedEventNotification,
)
from stripe.events._v1_tax_rate_updated_event import (
    V1TaxRateUpdatedEvent as V1TaxRateUpdatedEvent,
    V1TaxRateUpdatedEventNotification as V1TaxRateUpdatedEventNotification,
)
from stripe.events._v1_terminal_reader_action_failed_event import (
    V1TerminalReaderActionFailedEvent as V1TerminalReaderActionFailedEvent,
    V1TerminalReaderActionFailedEventNotification as V1TerminalReaderActionFailedEventNotification,
)
from stripe.events._v1_terminal_reader_action_succeeded_event import (
    V1TerminalReaderActionSucceededEvent as V1TerminalReaderActionSucceededEvent,
    V1TerminalReaderActionSucceededEventNotification as V1TerminalReaderActionSucceededEventNotification,
)
from stripe.events._v1_terminal_reader_action_updated_event import (
    V1TerminalReaderActionUpdatedEvent as V1TerminalReaderActionUpdatedEvent,
    V1TerminalReaderActionUpdatedEventNotification as V1TerminalReaderActionUpdatedEventNotification,
)
from stripe.events._v1_test_helpers_test_clock_advancing_event import (
    V1TestHelpersTestClockAdvancingEvent as V1TestHelpersTestClockAdvancingEvent,
    V1TestHelpersTestClockAdvancingEventNotification as V1TestHelpersTestClockAdvancingEventNotification,
)
from stripe.events._v1_test_helpers_test_clock_created_event import (
    V1TestHelpersTestClockCreatedEvent as V1TestHelpersTestClockCreatedEvent,
    V1TestHelpersTestClockCreatedEventNotification as V1TestHelpersTestClockCreatedEventNotification,
)
from stripe.events._v1_test_helpers_test_clock_deleted_event import (
    V1TestHelpersTestClockDeletedEvent as V1TestHelpersTestClockDeletedEvent,
    V1TestHelpersTestClockDeletedEventNotification as V1TestHelpersTestClockDeletedEventNotification,
)
from stripe.events._v1_test_helpers_test_clock_internal_failure_event import (
    V1TestHelpersTestClockInternalFailureEvent as V1TestHelpersTestClockInternalFailureEvent,
    V1TestHelpersTestClockInternalFailureEventNotification as V1TestHelpersTestClockInternalFailureEventNotification,
)
from stripe.events._v1_test_helpers_test_clock_ready_event import (
    V1TestHelpersTestClockReadyEvent as V1TestHelpersTestClockReadyEvent,
    V1TestHelpersTestClockReadyEventNotification as V1TestHelpersTestClockReadyEventNotification,
)
from stripe.events._v1_topup_canceled_event import (
    V1TopupCanceledEvent as V1TopupCanceledEvent,
    V1TopupCanceledEventNotification as V1TopupCanceledEventNotification,
)
from stripe.events._v1_topup_created_event import (
    V1TopupCreatedEvent as V1TopupCreatedEvent,
    V1TopupCreatedEventNotification as V1TopupCreatedEventNotification,
)
from stripe.events._v1_topup_failed_event import (
    V1TopupFailedEvent as V1TopupFailedEvent,
    V1TopupFailedEventNotification as V1TopupFailedEventNotification,
)
from stripe.events._v1_topup_reversed_event import (
    V1TopupReversedEvent as V1TopupReversedEvent,
    V1TopupReversedEventNotification as V1TopupReversedEventNotification,
)
from stripe.events._v1_topup_succeeded_event import (
    V1TopupSucceededEvent as V1TopupSucceededEvent,
    V1TopupSucceededEventNotification as V1TopupSucceededEventNotification,
)
from stripe.events._v1_transfer_created_event import (
    V1TransferCreatedEvent as V1TransferCreatedEvent,
    V1TransferCreatedEventNotification as V1TransferCreatedEventNotification,
)
from stripe.events._v1_transfer_reversed_event import (
    V1TransferReversedEvent as V1TransferReversedEvent,
    V1TransferReversedEventNotification as V1TransferReversedEventNotification,
)
from stripe.events._v1_transfer_updated_event import (
    V1TransferUpdatedEvent as V1TransferUpdatedEvent,
    V1TransferUpdatedEventNotification as V1TransferUpdatedEventNotification,
)
from stripe.events._v2_billing_cadence_billed_event import (
    V2BillingCadenceBilledEvent as V2BillingCadenceBilledEvent,
    V2BillingCadenceBilledEventNotification as V2BillingCadenceBilledEventNotification,
)
from stripe.events._v2_billing_cadence_canceled_event import (
    V2BillingCadenceCanceledEvent as V2BillingCadenceCanceledEvent,
    V2BillingCadenceCanceledEventNotification as V2BillingCadenceCanceledEventNotification,
)
from stripe.events._v2_billing_cadence_created_event import (
    V2BillingCadenceCreatedEvent as V2BillingCadenceCreatedEvent,
    V2BillingCadenceCreatedEventNotification as V2BillingCadenceCreatedEventNotification,
)
from stripe.events._v2_billing_license_fee_created_event import (
    V2BillingLicenseFeeCreatedEvent as V2BillingLicenseFeeCreatedEvent,
    V2BillingLicenseFeeCreatedEventNotification as V2BillingLicenseFeeCreatedEventNotification,
)
from stripe.events._v2_billing_license_fee_updated_event import (
    V2BillingLicenseFeeUpdatedEvent as V2BillingLicenseFeeUpdatedEvent,
    V2BillingLicenseFeeUpdatedEventNotification as V2BillingLicenseFeeUpdatedEventNotification,
)
from stripe.events._v2_billing_license_fee_version_created_event import (
    V2BillingLicenseFeeVersionCreatedEvent as V2BillingLicenseFeeVersionCreatedEvent,
    V2BillingLicenseFeeVersionCreatedEventNotification as V2BillingLicenseFeeVersionCreatedEventNotification,
)
from stripe.events._v2_billing_licensed_item_created_event import (
    V2BillingLicensedItemCreatedEvent as V2BillingLicensedItemCreatedEvent,
    V2BillingLicensedItemCreatedEventNotification as V2BillingLicensedItemCreatedEventNotification,
)
from stripe.events._v2_billing_licensed_item_updated_event import (
    V2BillingLicensedItemUpdatedEvent as V2BillingLicensedItemUpdatedEvent,
    V2BillingLicensedItemUpdatedEventNotification as V2BillingLicensedItemUpdatedEventNotification,
)
from stripe.events._v2_billing_metered_item_created_event import (
    V2BillingMeteredItemCreatedEvent as V2BillingMeteredItemCreatedEvent,
    V2BillingMeteredItemCreatedEventNotification as V2BillingMeteredItemCreatedEventNotification,
)
from stripe.events._v2_billing_metered_item_updated_event import (
    V2BillingMeteredItemUpdatedEvent as V2BillingMeteredItemUpdatedEvent,
    V2BillingMeteredItemUpdatedEventNotification as V2BillingMeteredItemUpdatedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_component_created_event import (
    V2BillingPricingPlanComponentCreatedEvent as V2BillingPricingPlanComponentCreatedEvent,
    V2BillingPricingPlanComponentCreatedEventNotification as V2BillingPricingPlanComponentCreatedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_component_updated_event import (
    V2BillingPricingPlanComponentUpdatedEvent as V2BillingPricingPlanComponentUpdatedEvent,
    V2BillingPricingPlanComponentUpdatedEventNotification as V2BillingPricingPlanComponentUpdatedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_created_event import (
    V2BillingPricingPlanCreatedEvent as V2BillingPricingPlanCreatedEvent,
    V2BillingPricingPlanCreatedEventNotification as V2BillingPricingPlanCreatedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_collection_awaiting_customer_action_event import (
    V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent as V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent,
    V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEventNotification as V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_collection_current_event import (
    V2BillingPricingPlanSubscriptionCollectionCurrentEvent as V2BillingPricingPlanSubscriptionCollectionCurrentEvent,
    V2BillingPricingPlanSubscriptionCollectionCurrentEventNotification as V2BillingPricingPlanSubscriptionCollectionCurrentEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_collection_past_due_event import (
    V2BillingPricingPlanSubscriptionCollectionPastDueEvent as V2BillingPricingPlanSubscriptionCollectionPastDueEvent,
    V2BillingPricingPlanSubscriptionCollectionPastDueEventNotification as V2BillingPricingPlanSubscriptionCollectionPastDueEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_collection_paused_event import (
    V2BillingPricingPlanSubscriptionCollectionPausedEvent as V2BillingPricingPlanSubscriptionCollectionPausedEvent,
    V2BillingPricingPlanSubscriptionCollectionPausedEventNotification as V2BillingPricingPlanSubscriptionCollectionPausedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_collection_unpaid_event import (
    V2BillingPricingPlanSubscriptionCollectionUnpaidEvent as V2BillingPricingPlanSubscriptionCollectionUnpaidEvent,
    V2BillingPricingPlanSubscriptionCollectionUnpaidEventNotification as V2BillingPricingPlanSubscriptionCollectionUnpaidEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_servicing_activated_event import (
    V2BillingPricingPlanSubscriptionServicingActivatedEvent as V2BillingPricingPlanSubscriptionServicingActivatedEvent,
    V2BillingPricingPlanSubscriptionServicingActivatedEventNotification as V2BillingPricingPlanSubscriptionServicingActivatedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_servicing_canceled_event import (
    V2BillingPricingPlanSubscriptionServicingCanceledEvent as V2BillingPricingPlanSubscriptionServicingCanceledEvent,
    V2BillingPricingPlanSubscriptionServicingCanceledEventNotification as V2BillingPricingPlanSubscriptionServicingCanceledEventNotification,
)
from stripe.events._v2_billing_pricing_plan_subscription_servicing_paused_event import (
    V2BillingPricingPlanSubscriptionServicingPausedEvent as V2BillingPricingPlanSubscriptionServicingPausedEvent,
    V2BillingPricingPlanSubscriptionServicingPausedEventNotification as V2BillingPricingPlanSubscriptionServicingPausedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_updated_event import (
    V2BillingPricingPlanUpdatedEvent as V2BillingPricingPlanUpdatedEvent,
    V2BillingPricingPlanUpdatedEventNotification as V2BillingPricingPlanUpdatedEventNotification,
)
from stripe.events._v2_billing_pricing_plan_version_created_event import (
    V2BillingPricingPlanVersionCreatedEvent as V2BillingPricingPlanVersionCreatedEvent,
    V2BillingPricingPlanVersionCreatedEventNotification as V2BillingPricingPlanVersionCreatedEventNotification,
)
from stripe.events._v2_billing_rate_card_created_event import (
    V2BillingRateCardCreatedEvent as V2BillingRateCardCreatedEvent,
    V2BillingRateCardCreatedEventNotification as V2BillingRateCardCreatedEventNotification,
)
from stripe.events._v2_billing_rate_card_rate_created_event import (
    V2BillingRateCardRateCreatedEvent as V2BillingRateCardRateCreatedEvent,
    V2BillingRateCardRateCreatedEventNotification as V2BillingRateCardRateCreatedEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_activated_event import (
    V2BillingRateCardSubscriptionActivatedEvent as V2BillingRateCardSubscriptionActivatedEvent,
    V2BillingRateCardSubscriptionActivatedEventNotification as V2BillingRateCardSubscriptionActivatedEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_canceled_event import (
    V2BillingRateCardSubscriptionCanceledEvent as V2BillingRateCardSubscriptionCanceledEvent,
    V2BillingRateCardSubscriptionCanceledEventNotification as V2BillingRateCardSubscriptionCanceledEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_collection_awaiting_customer_action_event import (
    V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent as V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent,
    V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEventNotification as V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_collection_current_event import (
    V2BillingRateCardSubscriptionCollectionCurrentEvent as V2BillingRateCardSubscriptionCollectionCurrentEvent,
    V2BillingRateCardSubscriptionCollectionCurrentEventNotification as V2BillingRateCardSubscriptionCollectionCurrentEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_collection_past_due_event import (
    V2BillingRateCardSubscriptionCollectionPastDueEvent as V2BillingRateCardSubscriptionCollectionPastDueEvent,
    V2BillingRateCardSubscriptionCollectionPastDueEventNotification as V2BillingRateCardSubscriptionCollectionPastDueEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_collection_paused_event import (
    V2BillingRateCardSubscriptionCollectionPausedEvent as V2BillingRateCardSubscriptionCollectionPausedEvent,
    V2BillingRateCardSubscriptionCollectionPausedEventNotification as V2BillingRateCardSubscriptionCollectionPausedEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_collection_unpaid_event import (
    V2BillingRateCardSubscriptionCollectionUnpaidEvent as V2BillingRateCardSubscriptionCollectionUnpaidEvent,
    V2BillingRateCardSubscriptionCollectionUnpaidEventNotification as V2BillingRateCardSubscriptionCollectionUnpaidEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_servicing_activated_event import (
    V2BillingRateCardSubscriptionServicingActivatedEvent as V2BillingRateCardSubscriptionServicingActivatedEvent,
    V2BillingRateCardSubscriptionServicingActivatedEventNotification as V2BillingRateCardSubscriptionServicingActivatedEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_servicing_canceled_event import (
    V2BillingRateCardSubscriptionServicingCanceledEvent as V2BillingRateCardSubscriptionServicingCanceledEvent,
    V2BillingRateCardSubscriptionServicingCanceledEventNotification as V2BillingRateCardSubscriptionServicingCanceledEventNotification,
)
from stripe.events._v2_billing_rate_card_subscription_servicing_paused_event import (
    V2BillingRateCardSubscriptionServicingPausedEvent as V2BillingRateCardSubscriptionServicingPausedEvent,
    V2BillingRateCardSubscriptionServicingPausedEventNotification as V2BillingRateCardSubscriptionServicingPausedEventNotification,
)
from stripe.events._v2_billing_rate_card_updated_event import (
    V2BillingRateCardUpdatedEvent as V2BillingRateCardUpdatedEvent,
    V2BillingRateCardUpdatedEventNotification as V2BillingRateCardUpdatedEventNotification,
)
from stripe.events._v2_billing_rate_card_version_created_event import (
    V2BillingRateCardVersionCreatedEvent as V2BillingRateCardVersionCreatedEvent,
    V2BillingRateCardVersionCreatedEventNotification as V2BillingRateCardVersionCreatedEventNotification,
)
from stripe.events._v2_core_account_closed_event import (
    V2CoreAccountClosedEvent as V2CoreAccountClosedEvent,
    V2CoreAccountClosedEventNotification as V2CoreAccountClosedEventNotification,
)
from stripe.events._v2_core_account_created_event import (
    V2CoreAccountCreatedEvent as V2CoreAccountCreatedEvent,
    V2CoreAccountCreatedEventNotification as V2CoreAccountCreatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_card_creator_capability_status_updated_event import (
    V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEvent,
    V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_card_creator_updated_event import (
    V2CoreAccountIncludingConfigurationCardCreatorUpdatedEvent as V2CoreAccountIncludingConfigurationCardCreatorUpdatedEvent,
    V2CoreAccountIncludingConfigurationCardCreatorUpdatedEventNotification as V2CoreAccountIncludingConfigurationCardCreatorUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_customer_capability_status_updated_event import (
    V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent,
    V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_customer_updated_event import (
    V2CoreAccountIncludingConfigurationCustomerUpdatedEvent as V2CoreAccountIncludingConfigurationCustomerUpdatedEvent,
    V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification as V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_merchant_capability_status_updated_event import (
    V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent,
    V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_merchant_updated_event import (
    V2CoreAccountIncludingConfigurationMerchantUpdatedEvent as V2CoreAccountIncludingConfigurationMerchantUpdatedEvent,
    V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification as V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_recipient_capability_status_updated_event import (
    V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent,
    V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_recipient_updated_event import (
    V2CoreAccountIncludingConfigurationRecipientUpdatedEvent as V2CoreAccountIncludingConfigurationRecipientUpdatedEvent,
    V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification as V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_storer_capability_status_updated_event import (
    V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent,
    V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_configuration_storer_updated_event import (
    V2CoreAccountIncludingConfigurationStorerUpdatedEvent as V2CoreAccountIncludingConfigurationStorerUpdatedEvent,
    V2CoreAccountIncludingConfigurationStorerUpdatedEventNotification as V2CoreAccountIncludingConfigurationStorerUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_defaults_updated_event import (
    V2CoreAccountIncludingDefaultsUpdatedEvent as V2CoreAccountIncludingDefaultsUpdatedEvent,
    V2CoreAccountIncludingDefaultsUpdatedEventNotification as V2CoreAccountIncludingDefaultsUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_identity_updated_event import (
    V2CoreAccountIncludingIdentityUpdatedEvent as V2CoreAccountIncludingIdentityUpdatedEvent,
    V2CoreAccountIncludingIdentityUpdatedEventNotification as V2CoreAccountIncludingIdentityUpdatedEventNotification,
)
from stripe.events._v2_core_account_including_requirements_updated_event import (
    V2CoreAccountIncludingRequirementsUpdatedEvent as V2CoreAccountIncludingRequirementsUpdatedEvent,
    V2CoreAccountIncludingRequirementsUpdatedEventNotification as V2CoreAccountIncludingRequirementsUpdatedEventNotification,
)
from stripe.events._v2_core_account_link_returned_event import (
    V2CoreAccountLinkReturnedEvent as V2CoreAccountLinkReturnedEvent,
    V2CoreAccountLinkReturnedEventNotification as V2CoreAccountLinkReturnedEventNotification,
)
from stripe.events._v2_core_account_person_created_event import (
    V2CoreAccountPersonCreatedEvent as V2CoreAccountPersonCreatedEvent,
    V2CoreAccountPersonCreatedEventNotification as V2CoreAccountPersonCreatedEventNotification,
)
from stripe.events._v2_core_account_person_deleted_event import (
    V2CoreAccountPersonDeletedEvent as V2CoreAccountPersonDeletedEvent,
    V2CoreAccountPersonDeletedEventNotification as V2CoreAccountPersonDeletedEventNotification,
)
from stripe.events._v2_core_account_person_updated_event import (
    V2CoreAccountPersonUpdatedEvent as V2CoreAccountPersonUpdatedEvent,
    V2CoreAccountPersonUpdatedEventNotification as V2CoreAccountPersonUpdatedEventNotification,
)
from stripe.events._v2_core_account_updated_event import (
    V2CoreAccountUpdatedEvent as V2CoreAccountUpdatedEvent,
    V2CoreAccountUpdatedEventNotification as V2CoreAccountUpdatedEventNotification,
)
from stripe.events._v2_core_claimable_sandbox_claimed_event import (
    V2CoreClaimableSandboxClaimedEvent as V2CoreClaimableSandboxClaimedEvent,
    V2CoreClaimableSandboxClaimedEventNotification as V2CoreClaimableSandboxClaimedEventNotification,
)
from stripe.events._v2_core_claimable_sandbox_created_event import (
    V2CoreClaimableSandboxCreatedEvent as V2CoreClaimableSandboxCreatedEvent,
    V2CoreClaimableSandboxCreatedEventNotification as V2CoreClaimableSandboxCreatedEventNotification,
)
from stripe.events._v2_core_claimable_sandbox_expired_event import (
    V2CoreClaimableSandboxExpiredEvent as V2CoreClaimableSandboxExpiredEvent,
    V2CoreClaimableSandboxExpiredEventNotification as V2CoreClaimableSandboxExpiredEventNotification,
)
from stripe.events._v2_core_claimable_sandbox_expiring_event import (
    V2CoreClaimableSandboxExpiringEvent as V2CoreClaimableSandboxExpiringEvent,
    V2CoreClaimableSandboxExpiringEventNotification as V2CoreClaimableSandboxExpiringEventNotification,
)
from stripe.events._v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event import (
    V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEvent as V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEvent,
    V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEventNotification as V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEventNotification,
)
from stripe.events._v2_core_event_destination_ping_event import (
    V2CoreEventDestinationPingEvent as V2CoreEventDestinationPingEvent,
    V2CoreEventDestinationPingEventNotification as V2CoreEventDestinationPingEventNotification,
)
from stripe.events._v2_core_health_api_error_firing_event import (
    V2CoreHealthApiErrorFiringEvent as V2CoreHealthApiErrorFiringEvent,
    V2CoreHealthApiErrorFiringEventNotification as V2CoreHealthApiErrorFiringEventNotification,
)
from stripe.events._v2_core_health_api_error_resolved_event import (
    V2CoreHealthApiErrorResolvedEvent as V2CoreHealthApiErrorResolvedEvent,
    V2CoreHealthApiErrorResolvedEventNotification as V2CoreHealthApiErrorResolvedEventNotification,
)
from stripe.events._v2_core_health_api_latency_firing_event import (
    V2CoreHealthApiLatencyFiringEvent as V2CoreHealthApiLatencyFiringEvent,
    V2CoreHealthApiLatencyFiringEventNotification as V2CoreHealthApiLatencyFiringEventNotification,
)
from stripe.events._v2_core_health_api_latency_resolved_event import (
    V2CoreHealthApiLatencyResolvedEvent as V2CoreHealthApiLatencyResolvedEvent,
    V2CoreHealthApiLatencyResolvedEventNotification as V2CoreHealthApiLatencyResolvedEventNotification,
)
from stripe.events._v2_core_health_authorization_rate_drop_firing_event import (
    V2CoreHealthAuthorizationRateDropFiringEvent as V2CoreHealthAuthorizationRateDropFiringEvent,
    V2CoreHealthAuthorizationRateDropFiringEventNotification as V2CoreHealthAuthorizationRateDropFiringEventNotification,
)
from stripe.events._v2_core_health_authorization_rate_drop_resolved_event import (
    V2CoreHealthAuthorizationRateDropResolvedEvent as V2CoreHealthAuthorizationRateDropResolvedEvent,
    V2CoreHealthAuthorizationRateDropResolvedEventNotification as V2CoreHealthAuthorizationRateDropResolvedEventNotification,
)
from stripe.events._v2_core_health_event_generation_failure_resolved_event import (
    V2CoreHealthEventGenerationFailureResolvedEvent as V2CoreHealthEventGenerationFailureResolvedEvent,
    V2CoreHealthEventGenerationFailureResolvedEventNotification as V2CoreHealthEventGenerationFailureResolvedEventNotification,
)
from stripe.events._v2_core_health_fraud_rate_increased_event import (
    V2CoreHealthFraudRateIncreasedEvent as V2CoreHealthFraudRateIncreasedEvent,
    V2CoreHealthFraudRateIncreasedEventNotification as V2CoreHealthFraudRateIncreasedEventNotification,
)
from stripe.events._v2_core_health_issuing_authorization_request_errors_firing_event import (
    V2CoreHealthIssuingAuthorizationRequestErrorsFiringEvent as V2CoreHealthIssuingAuthorizationRequestErrorsFiringEvent,
    V2CoreHealthIssuingAuthorizationRequestErrorsFiringEventNotification as V2CoreHealthIssuingAuthorizationRequestErrorsFiringEventNotification,
)
from stripe.events._v2_core_health_issuing_authorization_request_errors_resolved_event import (
    V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEvent as V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEvent,
    V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEventNotification as V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEventNotification,
)
from stripe.events._v2_core_health_issuing_authorization_request_timeout_firing_event import (
    V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent as V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent,
    V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEventNotification as V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEventNotification,
)
from stripe.events._v2_core_health_issuing_authorization_request_timeout_resolved_event import (
    V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent as V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent,
    V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEventNotification as V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEventNotification,
)
from stripe.events._v2_core_health_payment_method_error_firing_event import (
    V2CoreHealthPaymentMethodErrorFiringEvent as V2CoreHealthPaymentMethodErrorFiringEvent,
    V2CoreHealthPaymentMethodErrorFiringEventNotification as V2CoreHealthPaymentMethodErrorFiringEventNotification,
)
from stripe.events._v2_core_health_payment_method_error_resolved_event import (
    V2CoreHealthPaymentMethodErrorResolvedEvent as V2CoreHealthPaymentMethodErrorResolvedEvent,
    V2CoreHealthPaymentMethodErrorResolvedEventNotification as V2CoreHealthPaymentMethodErrorResolvedEventNotification,
)
from stripe.events._v2_core_health_traffic_volume_drop_firing_event import (
    V2CoreHealthTrafficVolumeDropFiringEvent as V2CoreHealthTrafficVolumeDropFiringEvent,
    V2CoreHealthTrafficVolumeDropFiringEventNotification as V2CoreHealthTrafficVolumeDropFiringEventNotification,
)
from stripe.events._v2_core_health_traffic_volume_drop_resolved_event import (
    V2CoreHealthTrafficVolumeDropResolvedEvent as V2CoreHealthTrafficVolumeDropResolvedEvent,
    V2CoreHealthTrafficVolumeDropResolvedEventNotification as V2CoreHealthTrafficVolumeDropResolvedEventNotification,
)
from stripe.events._v2_core_health_webhook_latency_firing_event import (
    V2CoreHealthWebhookLatencyFiringEvent as V2CoreHealthWebhookLatencyFiringEvent,
    V2CoreHealthWebhookLatencyFiringEventNotification as V2CoreHealthWebhookLatencyFiringEventNotification,
)
from stripe.events._v2_core_health_webhook_latency_resolved_event import (
    V2CoreHealthWebhookLatencyResolvedEvent as V2CoreHealthWebhookLatencyResolvedEvent,
    V2CoreHealthWebhookLatencyResolvedEventNotification as V2CoreHealthWebhookLatencyResolvedEventNotification,
)
from stripe.events._v2_money_management_adjustment_created_event import (
    V2MoneyManagementAdjustmentCreatedEvent as V2MoneyManagementAdjustmentCreatedEvent,
    V2MoneyManagementAdjustmentCreatedEventNotification as V2MoneyManagementAdjustmentCreatedEventNotification,
)
from stripe.events._v2_money_management_financial_account_created_event import (
    V2MoneyManagementFinancialAccountCreatedEvent as V2MoneyManagementFinancialAccountCreatedEvent,
    V2MoneyManagementFinancialAccountCreatedEventNotification as V2MoneyManagementFinancialAccountCreatedEventNotification,
)
from stripe.events._v2_money_management_financial_account_updated_event import (
    V2MoneyManagementFinancialAccountUpdatedEvent as V2MoneyManagementFinancialAccountUpdatedEvent,
    V2MoneyManagementFinancialAccountUpdatedEventNotification as V2MoneyManagementFinancialAccountUpdatedEventNotification,
)
from stripe.events._v2_money_management_financial_address_activated_event import (
    V2MoneyManagementFinancialAddressActivatedEvent as V2MoneyManagementFinancialAddressActivatedEvent,
    V2MoneyManagementFinancialAddressActivatedEventNotification as V2MoneyManagementFinancialAddressActivatedEventNotification,
)
from stripe.events._v2_money_management_financial_address_failed_event import (
    V2MoneyManagementFinancialAddressFailedEvent as V2MoneyManagementFinancialAddressFailedEvent,
    V2MoneyManagementFinancialAddressFailedEventNotification as V2MoneyManagementFinancialAddressFailedEventNotification,
)
from stripe.events._v2_money_management_inbound_transfer_available_event import (
    V2MoneyManagementInboundTransferAvailableEvent as V2MoneyManagementInboundTransferAvailableEvent,
    V2MoneyManagementInboundTransferAvailableEventNotification as V2MoneyManagementInboundTransferAvailableEventNotification,
)
from stripe.events._v2_money_management_inbound_transfer_bank_debit_failed_event import (
    V2MoneyManagementInboundTransferBankDebitFailedEvent as V2MoneyManagementInboundTransferBankDebitFailedEvent,
    V2MoneyManagementInboundTransferBankDebitFailedEventNotification as V2MoneyManagementInboundTransferBankDebitFailedEventNotification,
)
from stripe.events._v2_money_management_inbound_transfer_bank_debit_processing_event import (
    V2MoneyManagementInboundTransferBankDebitProcessingEvent as V2MoneyManagementInboundTransferBankDebitProcessingEvent,
    V2MoneyManagementInboundTransferBankDebitProcessingEventNotification as V2MoneyManagementInboundTransferBankDebitProcessingEventNotification,
)
from stripe.events._v2_money_management_inbound_transfer_bank_debit_queued_event import (
    V2MoneyManagementInboundTransferBankDebitQueuedEvent as V2MoneyManagementInboundTransferBankDebitQueuedEvent,
    V2MoneyManagementInboundTransferBankDebitQueuedEventNotification as V2MoneyManagementInboundTransferBankDebitQueuedEventNotification,
)
from stripe.events._v2_money_management_inbound_transfer_bank_debit_returned_event import (
    V2MoneyManagementInboundTransferBankDebitReturnedEvent as V2MoneyManagementInboundTransferBankDebitReturnedEvent,
    V2MoneyManagementInboundTransferBankDebitReturnedEventNotification as V2MoneyManagementInboundTransferBankDebitReturnedEventNotification,
)
from stripe.events._v2_money_management_inbound_transfer_bank_debit_succeeded_event import (
    V2MoneyManagementInboundTransferBankDebitSucceededEvent as V2MoneyManagementInboundTransferBankDebitSucceededEvent,
    V2MoneyManagementInboundTransferBankDebitSucceededEventNotification as V2MoneyManagementInboundTransferBankDebitSucceededEventNotification,
)
from stripe.events._v2_money_management_outbound_payment_canceled_event import (
    V2MoneyManagementOutboundPaymentCanceledEvent as V2MoneyManagementOutboundPaymentCanceledEvent,
    V2MoneyManagementOutboundPaymentCanceledEventNotification as V2MoneyManagementOutboundPaymentCanceledEventNotification,
)
from stripe.events._v2_money_management_outbound_payment_created_event import (
    V2MoneyManagementOutboundPaymentCreatedEvent as V2MoneyManagementOutboundPaymentCreatedEvent,
    V2MoneyManagementOutboundPaymentCreatedEventNotification as V2MoneyManagementOutboundPaymentCreatedEventNotification,
)
from stripe.events._v2_money_management_outbound_payment_failed_event import (
    V2MoneyManagementOutboundPaymentFailedEvent as V2MoneyManagementOutboundPaymentFailedEvent,
    V2MoneyManagementOutboundPaymentFailedEventNotification as V2MoneyManagementOutboundPaymentFailedEventNotification,
)
from stripe.events._v2_money_management_outbound_payment_posted_event import (
    V2MoneyManagementOutboundPaymentPostedEvent as V2MoneyManagementOutboundPaymentPostedEvent,
    V2MoneyManagementOutboundPaymentPostedEventNotification as V2MoneyManagementOutboundPaymentPostedEventNotification,
)
from stripe.events._v2_money_management_outbound_payment_returned_event import (
    V2MoneyManagementOutboundPaymentReturnedEvent as V2MoneyManagementOutboundPaymentReturnedEvent,
    V2MoneyManagementOutboundPaymentReturnedEventNotification as V2MoneyManagementOutboundPaymentReturnedEventNotification,
)
from stripe.events._v2_money_management_outbound_payment_updated_event import (
    V2MoneyManagementOutboundPaymentUpdatedEvent as V2MoneyManagementOutboundPaymentUpdatedEvent,
    V2MoneyManagementOutboundPaymentUpdatedEventNotification as V2MoneyManagementOutboundPaymentUpdatedEventNotification,
)
from stripe.events._v2_money_management_outbound_transfer_canceled_event import (
    V2MoneyManagementOutboundTransferCanceledEvent as V2MoneyManagementOutboundTransferCanceledEvent,
    V2MoneyManagementOutboundTransferCanceledEventNotification as V2MoneyManagementOutboundTransferCanceledEventNotification,
)
from stripe.events._v2_money_management_outbound_transfer_created_event import (
    V2MoneyManagementOutboundTransferCreatedEvent as V2MoneyManagementOutboundTransferCreatedEvent,
    V2MoneyManagementOutboundTransferCreatedEventNotification as V2MoneyManagementOutboundTransferCreatedEventNotification,
)
from stripe.events._v2_money_management_outbound_transfer_failed_event import (
    V2MoneyManagementOutboundTransferFailedEvent as V2MoneyManagementOutboundTransferFailedEvent,
    V2MoneyManagementOutboundTransferFailedEventNotification as V2MoneyManagementOutboundTransferFailedEventNotification,
)
from stripe.events._v2_money_management_outbound_transfer_posted_event import (
    V2MoneyManagementOutboundTransferPostedEvent as V2MoneyManagementOutboundTransferPostedEvent,
    V2MoneyManagementOutboundTransferPostedEventNotification as V2MoneyManagementOutboundTransferPostedEventNotification,
)
from stripe.events._v2_money_management_outbound_transfer_returned_event import (
    V2MoneyManagementOutboundTransferReturnedEvent as V2MoneyManagementOutboundTransferReturnedEvent,
    V2MoneyManagementOutboundTransferReturnedEventNotification as V2MoneyManagementOutboundTransferReturnedEventNotification,
)
from stripe.events._v2_money_management_outbound_transfer_updated_event import (
    V2MoneyManagementOutboundTransferUpdatedEvent as V2MoneyManagementOutboundTransferUpdatedEvent,
    V2MoneyManagementOutboundTransferUpdatedEventNotification as V2MoneyManagementOutboundTransferUpdatedEventNotification,
)
from stripe.events._v2_money_management_payout_method_updated_event import (
    V2MoneyManagementPayoutMethodUpdatedEvent as V2MoneyManagementPayoutMethodUpdatedEvent,
    V2MoneyManagementPayoutMethodUpdatedEventNotification as V2MoneyManagementPayoutMethodUpdatedEventNotification,
)
from stripe.events._v2_money_management_received_credit_available_event import (
    V2MoneyManagementReceivedCreditAvailableEvent as V2MoneyManagementReceivedCreditAvailableEvent,
    V2MoneyManagementReceivedCreditAvailableEventNotification as V2MoneyManagementReceivedCreditAvailableEventNotification,
)
from stripe.events._v2_money_management_received_credit_failed_event import (
    V2MoneyManagementReceivedCreditFailedEvent as V2MoneyManagementReceivedCreditFailedEvent,
    V2MoneyManagementReceivedCreditFailedEventNotification as V2MoneyManagementReceivedCreditFailedEventNotification,
)
from stripe.events._v2_money_management_received_credit_returned_event import (
    V2MoneyManagementReceivedCreditReturnedEvent as V2MoneyManagementReceivedCreditReturnedEvent,
    V2MoneyManagementReceivedCreditReturnedEventNotification as V2MoneyManagementReceivedCreditReturnedEventNotification,
)
from stripe.events._v2_money_management_received_credit_succeeded_event import (
    V2MoneyManagementReceivedCreditSucceededEvent as V2MoneyManagementReceivedCreditSucceededEvent,
    V2MoneyManagementReceivedCreditSucceededEventNotification as V2MoneyManagementReceivedCreditSucceededEventNotification,
)
from stripe.events._v2_money_management_received_debit_canceled_event import (
    V2MoneyManagementReceivedDebitCanceledEvent as V2MoneyManagementReceivedDebitCanceledEvent,
    V2MoneyManagementReceivedDebitCanceledEventNotification as V2MoneyManagementReceivedDebitCanceledEventNotification,
)
from stripe.events._v2_money_management_received_debit_failed_event import (
    V2MoneyManagementReceivedDebitFailedEvent as V2MoneyManagementReceivedDebitFailedEvent,
    V2MoneyManagementReceivedDebitFailedEventNotification as V2MoneyManagementReceivedDebitFailedEventNotification,
)
from stripe.events._v2_money_management_received_debit_pending_event import (
    V2MoneyManagementReceivedDebitPendingEvent as V2MoneyManagementReceivedDebitPendingEvent,
    V2MoneyManagementReceivedDebitPendingEventNotification as V2MoneyManagementReceivedDebitPendingEventNotification,
)
from stripe.events._v2_money_management_received_debit_succeeded_event import (
    V2MoneyManagementReceivedDebitSucceededEvent as V2MoneyManagementReceivedDebitSucceededEvent,
    V2MoneyManagementReceivedDebitSucceededEventNotification as V2MoneyManagementReceivedDebitSucceededEventNotification,
)
from stripe.events._v2_money_management_received_debit_updated_event import (
    V2MoneyManagementReceivedDebitUpdatedEvent as V2MoneyManagementReceivedDebitUpdatedEvent,
    V2MoneyManagementReceivedDebitUpdatedEventNotification as V2MoneyManagementReceivedDebitUpdatedEventNotification,
)
from stripe.events._v2_money_management_recipient_verification_created_event import (
    V2MoneyManagementRecipientVerificationCreatedEvent as V2MoneyManagementRecipientVerificationCreatedEvent,
    V2MoneyManagementRecipientVerificationCreatedEventNotification as V2MoneyManagementRecipientVerificationCreatedEventNotification,
)
from stripe.events._v2_money_management_recipient_verification_updated_event import (
    V2MoneyManagementRecipientVerificationUpdatedEvent as V2MoneyManagementRecipientVerificationUpdatedEvent,
    V2MoneyManagementRecipientVerificationUpdatedEventNotification as V2MoneyManagementRecipientVerificationUpdatedEventNotification,
)
from stripe.events._v2_money_management_transaction_created_event import (
    V2MoneyManagementTransactionCreatedEvent as V2MoneyManagementTransactionCreatedEvent,
    V2MoneyManagementTransactionCreatedEventNotification as V2MoneyManagementTransactionCreatedEventNotification,
)
from stripe.events._v2_money_management_transaction_updated_event import (
    V2MoneyManagementTransactionUpdatedEvent as V2MoneyManagementTransactionUpdatedEvent,
    V2MoneyManagementTransactionUpdatedEventNotification as V2MoneyManagementTransactionUpdatedEventNotification,
)
from stripe.events._v2_payments_off_session_payment_authorization_attempt_failed_event import (
    V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent as V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent,
    V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEventNotification as V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEventNotification,
)
from stripe.events._v2_payments_off_session_payment_authorization_attempt_started_event import (
    V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent as V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent,
    V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEventNotification as V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEventNotification,
)
from stripe.events._v2_payments_off_session_payment_canceled_event import (
    V2PaymentsOffSessionPaymentCanceledEvent as V2PaymentsOffSessionPaymentCanceledEvent,
    V2PaymentsOffSessionPaymentCanceledEventNotification as V2PaymentsOffSessionPaymentCanceledEventNotification,
)
from stripe.events._v2_payments_off_session_payment_created_event import (
    V2PaymentsOffSessionPaymentCreatedEvent as V2PaymentsOffSessionPaymentCreatedEvent,
    V2PaymentsOffSessionPaymentCreatedEventNotification as V2PaymentsOffSessionPaymentCreatedEventNotification,
)
from stripe.events._v2_payments_off_session_payment_failed_event import (
    V2PaymentsOffSessionPaymentFailedEvent as V2PaymentsOffSessionPaymentFailedEvent,
    V2PaymentsOffSessionPaymentFailedEventNotification as V2PaymentsOffSessionPaymentFailedEventNotification,
)
from stripe.events._v2_payments_off_session_payment_requires_capture_event import (
    V2PaymentsOffSessionPaymentRequiresCaptureEvent as V2PaymentsOffSessionPaymentRequiresCaptureEvent,
    V2PaymentsOffSessionPaymentRequiresCaptureEventNotification as V2PaymentsOffSessionPaymentRequiresCaptureEventNotification,
)
from stripe.events._v2_payments_off_session_payment_succeeded_event import (
    V2PaymentsOffSessionPaymentSucceededEvent as V2PaymentsOffSessionPaymentSucceededEvent,
    V2PaymentsOffSessionPaymentSucceededEventNotification as V2PaymentsOffSessionPaymentSucceededEventNotification,
)
# The end of the section generated from our OpenAPI spec



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from stripe.v2.core.vault._us_bank_account import UsBankAccount
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.core.vault._us_bank_account_archive_params import (
        UsBankAccountArchiveParams,
    )
    from stripe.params.v2.core.vault._us_bank_account_create_params import (
        UsBankAccountCreateParams,
    )
    from stripe.params.v2.core.vault._us_bank_account_retrieve_params import (
        UsBankAccountRetrieveParams,
    )
    from stripe.params.v2.core.vault._us_bank_account_update_params import (
        UsBankAccountUpdateParams,
    )


class UsBankAccountService(StripeService):
    def create(
        self,
        params: "UsBankAccountCreateParams",
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Create a USBankAccount object.
        """
        return cast(
            UsBankAccount,
            self._request(
                "post",
                "/v2/core/vault/us_bank_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "UsBankAccountCreateParams",
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Create a USBankAccount object.
        """
        return cast(
            UsBankAccount,
            await self._request_async(
                "post",
                "/v2/core/vault/us_bank_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["UsBankAccountRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Retrieve a USBankAccount object.
        """
        return cast(
            UsBankAccount,
            self._request(
                "get",
                "/v2/core/vault/us_bank_accounts/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["UsBankAccountRetrieveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Retrieve a USBankAccount object.
        """
        return cast(
            UsBankAccount,
            await self._request_async(
                "get",
                "/v2/core/vault/us_bank_accounts/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        id: str,
        params: Optional["UsBankAccountUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Update a USBankAccount object. This is limited to supplying a previously empty routing_number field.
        """
        return cast(
            UsBankAccount,
            self._request(
                "post",
                "/v2/core/vault/us_bank_accounts/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        id: str,
        params: Optional["UsBankAccountUpdateParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Update a USBankAccount object. This is limited to supplying a previously empty routing_number field.
        """
        return cast(
            UsBankAccount,
            await self._request_async(
                "post",
                "/v2/core/vault/us_bank_accounts/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def archive(
        self,
        id: str,
        params: Optional["UsBankAccountArchiveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Archive a USBankAccount object. USBankAccount objects will not be automatically archived by Stripe.
        Archived USBankAccount objects cannot be used as outbound destinations
        and will not appear in the outbound destination list.
        """
        return cast(
            UsBankAccount,
            self._request(
                "post",
                "/v2/core/vault/us_bank_accounts/{id}/archive".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def archive_async(
        self,
        id: str,
        params: Optional["UsBankAccountArchiveParams"] = None,
        options: Optional[RequestOptions] = None,
    ) -> UsBankAccount:
        """
        Archive a USBankAccount object. USBankAccount objects will not be automatically archived by Stripe.
        Archived USBankAccount objects cannot be used as outbound destinations
        and will not appear in the outbound destination list.
        """
        return cast(
            UsBankAccount,
            await self._request_async(
                "post",
                "/v2/core/vault/us_bank_accounts/{id}/archive".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import TypedDict


class AutomaticRuleUpdateParams(TypedDict):
    tax_code: str
    """
    The TaxCode object to be used for automatic tax calculations.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import NotRequired


class PaymentAttemptRecordListParams(RequestOptions):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    limit: NotRequired[int]
    """
    A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
    """
    payment_record: str
    """
    The ID of the Payment Record.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.identity._blocklist_entry_create_params import (
    BlocklistEntryCreateParams as BlocklistEntryCreateParams,
)
from stripe.params.identity._blocklist_entry_disable_params import (
    BlocklistEntryDisableParams as BlocklistEntryDisableParams,
)
from stripe.params.identity._blocklist_entry_list_params import (
    BlocklistEntryListParams as BlocklistEntryListParams,
    BlocklistEntryListParamsCreated as BlocklistEntryListParamsCreated,
)
from stripe.params.identity._blocklist_entry_retrieve_params import (
    BlocklistEntryRetrieveParams as BlocklistEntryRetrieveParams,
)
from stripe.params.identity._verification_report_list_params import (
    VerificationReportListParams as VerificationReportListParams,
    VerificationReportListParamsCreated as VerificationReportListParamsCreated,
)
from stripe.params.identity._verification_report_retrieve_params import (
    VerificationReportRetrieveParams as VerificationReportRetrieveParams,
)
from stripe.params.identity._verification_session_cancel_params import (
    VerificationSessionCancelParams as VerificationSessionCancelParams,
)
from stripe.params.identity._verification_session_create_params import (
    VerificationSessionCreateParams as VerificationSessionCreateParams,
    VerificationSessionCreateParamsOptions as VerificationSessionCreateParamsOptions,
    VerificationSessionCreateParamsOptionsDocument as VerificationSessionCreateParamsOptionsDocument,
    VerificationSessionCreateParamsProvidedDetails as VerificationSessionCreateParamsProvidedDetails,
    VerificationSessionCreateParamsRelatedPerson as VerificationSessionCreateParamsRelatedPerson,
)
from stripe.params.identity._verification_session_list_params import (
    VerificationSessionListParams as VerificationSessionListParams,
    VerificationSessionListParamsCreated as VerificationSessionListParamsCreated,
)
from stripe.params.identity._verification_session_modify_params import (
    VerificationSessionModifyParams as VerificationSessionModifyParams,
    VerificationSessionModifyParamsOptions as VerificationSessionModifyParamsOptions,
    VerificationSessionModifyParamsOptionsDocument as VerificationSessionModifyParamsOptionsDocument,
    VerificationSessionModifyParamsProvidedDetails as VerificationSessionModifyParamsProvidedDetails,
)
from stripe.params.identity._verification_session_redact_params import (
    VerificationSessionRedactParams as VerificationSessionRedactParams,
)
from stripe.params.identity._verification_session_retrieve_params import (
    VerificationSessionRetrieveParams as VerificationSessionRetrieveParams,
)
from stripe.params.identity._verification_session_update_params import (
    VerificationSessionUpdateParams as VerificationSessionUpdateParams,
    VerificationSessionUpdateParamsOptions as VerificationSessionUpdateParamsOptions,
    VerificationSessionUpdateParamsOptionsDocument as VerificationSessionUpdateParamsOptionsDocument,
    VerificationSessionUpdateParamsProvidedDetails as VerificationSessionUpdateParamsProvidedDetails,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._account_link_service import AccountLinkService
from stripe._account_notice_service import AccountNoticeService
from stripe._account_service import AccountService
from stripe._account_session_service import AccountSessionService
from stripe._apple_pay_domain_service import ApplePayDomainService
from stripe._application_fee_service import ApplicationFeeService
from stripe._apps_service import AppsService
from stripe._balance_service import BalanceService
from stripe._balance_settings_service import BalanceSettingsService
from stripe._balance_transaction_service import BalanceTransactionService
from stripe._billing_portal_service import BillingPortalService
from stripe._billing_service import BillingService
from stripe._capital_service import CapitalService
from stripe._charge_service import ChargeService
from stripe._checkout_service import CheckoutService
from stripe._climate_service import ClimateService
from stripe._confirmation_token_service import ConfirmationTokenService
from stripe._country_spec_service import CountrySpecService
from stripe._coupon_service import CouponService
from stripe._credit_note_service import CreditNoteService
from stripe._customer_service import CustomerService
from stripe._customer_session_service import CustomerSessionService
from stripe._delegated_checkout_service import DelegatedCheckoutService
from stripe._dispute_service import DisputeService
from stripe._entitlements_service import EntitlementsService
from stripe._ephemeral_key_service import EphemeralKeyService
from stripe._event_service import EventService
from stripe._exchange_rate_service import ExchangeRateService
from stripe._external_account_service import ExternalAccountService
from stripe._file_link_service import FileLinkService
from stripe._file_service import FileService
from stripe._financial_connections_service import FinancialConnectionsService
from stripe._forwarding_service import ForwardingService
from stripe._fx_quote_service import FxQuoteService
from stripe._identity_service import IdentityService
from stripe._invoice_item_service import InvoiceItemService
from stripe._invoice_payment_service import InvoicePaymentService
from stripe._invoice_rendering_template_service import (
    InvoiceRenderingTemplateService,
)
from stripe._invoice_service import InvoiceService
from stripe._issuing_service import IssuingService
from stripe._mandate_service import MandateService
from stripe._margin_service import MarginService
from stripe._order_service import OrderService
from stripe._payment_attempt_record_service import PaymentAttemptRecordService
from stripe._payment_intent_service import PaymentIntentService
from stripe._payment_link_service import PaymentLinkService
from stripe._payment_method_configuration_service import (
    PaymentMethodConfigurationService,
)
from stripe._payment_method_domain_service import PaymentMethodDomainService
from stripe._payment_method_service import PaymentMethodService
from stripe._payment_record_service import PaymentRecordService
from stripe._payout_service import PayoutService
from stripe._plan_service import PlanService
from stripe._price_service import PriceService
from stripe._privacy_service import PrivacyService
from stripe._product_service import ProductService
from stripe._promotion_code_service import PromotionCodeService
from stripe._quote_service import QuoteService
from stripe._radar_service import RadarService
from stripe._refund_service import RefundService
from stripe._reporting_service import ReportingService
from stripe._review_service import ReviewService
from stripe._setup_attempt_service import SetupAttemptService
from stripe._setup_intent_service import SetupIntentService
from stripe._shipping_rate_service import ShippingRateService
from stripe._sigma_service import SigmaService
from stripe._source_service import SourceService
from stripe._stripe_service import StripeService
from stripe._subscription_item_service import SubscriptionItemService
from stripe._subscription_schedule_service import SubscriptionScheduleService
from stripe._subscription_service import SubscriptionService
from stripe._tax_code_service import TaxCodeService
from stripe._tax_id_service import TaxIdService
from stripe._tax_rate_service import TaxRateService
from stripe._tax_service import TaxService
from stripe._terminal_service import TerminalService
from stripe._test_helpers_service import TestHelpersService
from stripe._token_service import TokenService
from stripe._topup_service import TopupService
from stripe._transfer_service import TransferService
from stripe._treasury_service import TreasuryService
from stripe._webhook_endpoint_service import WebhookEndpointService


class V1Services(StripeService):
    def __init__(self, requestor):
        super().__init__(requestor)
        self.accounts = AccountService(self._requestor)
        self.account_links = AccountLinkService(self._requestor)
        self.account_notices = AccountNoticeService(self._requestor)
        self.account_sessions = AccountSessionService(self._requestor)
        self.apple_pay_domains = ApplePayDomainService(self._requestor)
        self.application_fees = ApplicationFeeService(self._requestor)
        self.apps = AppsService(self._requestor)
        self.balance = BalanceService(self._requestor)
        self.balance_settings = BalanceSettingsService(self._requestor)
        self.balance_transactions = BalanceTransactionService(self._requestor)
        self.billing = BillingService(self._requestor)
        self.billing_portal = BillingPortalService(self._requestor)
        self.capital = CapitalService(self._requestor)
        self.charges = ChargeService(self._requestor)
        self.checkout = CheckoutService(self._requestor)
        self.climate = ClimateService(self._requestor)
        self.confirmation_tokens = ConfirmationTokenService(self._requestor)
        self.country_specs = CountrySpecService(self._requestor)
        self.coupons = CouponService(self._requestor)
        self.credit_notes = CreditNoteService(self._requestor)
        self.customers = CustomerService(self._requestor)
        self.customer_sessions = CustomerSessionService(self._requestor)
        self.delegated_checkout = DelegatedCheckoutService(self._requestor)
        self.disputes = DisputeService(self._requestor)
        self.entitlements = EntitlementsService(self._requestor)
        self.ephemeral_keys = EphemeralKeyService(self._requestor)
        self.events = EventService(self._requestor)
        self.exchange_rates = ExchangeRateService(self._requestor)
        self.external_accounts = ExternalAccountService(self._requestor)
        self.files = FileService(self._requestor)
        self.file_links = FileLinkService(self._requestor)
        self.financial_connections = FinancialConnectionsService(
            self._requestor,
        )
        self.forwarding = ForwardingService(self._requestor)
        self.fx_quotes = FxQuoteService(self._requestor)
        self.identity = IdentityService(self._requestor)
        self.invoices = InvoiceService(self._requestor)
        self.invoice_items = InvoiceItemService(self._requestor)
        self.invoice_payments = InvoicePaymentService(self._requestor)
        self.invoice_rendering_templates = InvoiceRenderingTemplateService(
            self._requestor,
        )
        self.issuing = IssuingService(self._requestor)
        self.mandates = MandateService(self._requestor)
        self.margins = MarginService(self._requestor)
        self.orders = OrderService(self._requestor)
        self.payment_attempt_records = PaymentAttemptRecordService(
            self._requestor,
        )
        self.payment_intents = PaymentIntentService(self._requestor)
        self.payment_links = PaymentLinkService(self._requestor)
        self.payment_methods = PaymentMethodService(self._requestor)
        self.payment_method_configurations = PaymentMethodConfigurationService(
            self._requestor,
        )
        self.payment_method_domains = PaymentMethodDomainService(
            self._requestor,
        )
        self.payment_records = PaymentRecordService(self._requestor)
        self.payouts = PayoutService(self._requestor)
        self.plans = PlanService(self._requestor)
        self.prices = PriceService(self._requestor)
        self.privacy = PrivacyService(self._requestor)
        self.products = ProductService(self._requestor)
        self.promotion_codes = PromotionCodeService(self._requestor)
        self.quotes = QuoteService(self._requestor)
        self.radar = RadarService(self._requestor)
        self.refunds = RefundService(self._requestor)
        self.reporting = ReportingService(self._requestor)
        self.reviews = ReviewService(self._requestor)
        self.setup_attempts = SetupAttemptService(self._requestor)
        self.setup_intents = SetupIntentService(self._requestor)
        self.shipping_rates = ShippingRateService(self._requestor)
        self.sigma = SigmaService(self._requestor)
        self.sources = SourceService(self._requestor)
        self.subscriptions = SubscriptionService(self._requestor)
        self.subscription_items = SubscriptionItemService(self._requestor)
        self.subscription_schedules = SubscriptionScheduleService(
            self._requestor,
        )
        self.tax = TaxService(self._requestor)
        self.tax_codes = TaxCodeService(self._requestor)
        self.tax_ids = TaxIdService(self._requestor)
        self.tax_rates = TaxRateService(self._requestor)
        self.terminal = TerminalService(self._requestor)
        self.test_helpers = TestHelpersService(self._requestor)
        self.tokens = TokenService(self._requestor)
        self.topups = TopupService(self._requestor)
        self.transfers = TransferService(self._requestor)
        self.treasury = TreasuryService(self._requestor)
        self.webhook_endpoints = WebhookEndpointService(self._requestor)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.issuing._authorization_approve_params import (
    AuthorizationApproveParams as AuthorizationApproveParams,
)
from stripe.params.issuing._authorization_capture_params import (
    AuthorizationCaptureParams as AuthorizationCaptureParams,
    AuthorizationCaptureParamsPurchaseDetails as AuthorizationCaptureParamsPurchaseDetails,
    AuthorizationCaptureParamsPurchaseDetailsFleet as AuthorizationCaptureParamsPurchaseDetailsFleet,
    AuthorizationCaptureParamsPurchaseDetailsFleetCardholderPromptData as AuthorizationCaptureParamsPurchaseDetailsFleetCardholderPromptData,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdown as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdown,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownTax as AuthorizationCaptureParamsPurchaseDetailsFleetReportedBreakdownTax,
    AuthorizationCaptureParamsPurchaseDetailsFlight as AuthorizationCaptureParamsPurchaseDetailsFlight,
    AuthorizationCaptureParamsPurchaseDetailsFlightSegment as AuthorizationCaptureParamsPurchaseDetailsFlightSegment,
    AuthorizationCaptureParamsPurchaseDetailsFuel as AuthorizationCaptureParamsPurchaseDetailsFuel,
    AuthorizationCaptureParamsPurchaseDetailsLodging as AuthorizationCaptureParamsPurchaseDetailsLodging,
    AuthorizationCaptureParamsPurchaseDetailsReceipt as AuthorizationCaptureParamsPurchaseDetailsReceipt,
)
from stripe.params.issuing._authorization_create_params import (
    AuthorizationCreateParams as AuthorizationCreateParams,
    AuthorizationCreateParamsAmountDetails as AuthorizationCreateParamsAmountDetails,
    AuthorizationCreateParamsFleet as AuthorizationCreateParamsFleet,
    AuthorizationCreateParamsFleetCardholderPromptData as AuthorizationCreateParamsFleetCardholderPromptData,
    AuthorizationCreateParamsFleetReportedBreakdown as AuthorizationCreateParamsFleetReportedBreakdown,
    AuthorizationCreateParamsFleetReportedBreakdownFuel as AuthorizationCreateParamsFleetReportedBreakdownFuel,
    AuthorizationCreateParamsFleetReportedBreakdownNonFuel as AuthorizationCreateParamsFleetReportedBreakdownNonFuel,
    AuthorizationCreateParamsFleetReportedBreakdownTax as AuthorizationCreateParamsFleetReportedBreakdownTax,
    AuthorizationCreateParamsFuel as AuthorizationCreateParamsFuel,
    AuthorizationCreateParamsMerchantData as AuthorizationCreateParamsMerchantData,
    AuthorizationCreateParamsNetworkData as AuthorizationCreateParamsNetworkData,
    AuthorizationCreateParamsRiskAssessment as AuthorizationCreateParamsRiskAssessment,
    AuthorizationCreateParamsRiskAssessmentCardTestingRisk as AuthorizationCreateParamsRiskAssessmentCardTestingRisk,
    AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk as AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk,
    AuthorizationCreateParamsVerificationData as AuthorizationCreateParamsVerificationData,
    AuthorizationCreateParamsVerificationDataAuthenticationExemption as AuthorizationCreateParamsVerificationDataAuthenticationExemption,
    AuthorizationCreateParamsVerificationDataThreeDSecure as AuthorizationCreateParamsVerificationDataThreeDSecure,
)
from stripe.params.issuing._authorization_decline_params import (
    AuthorizationDeclineParams as AuthorizationDeclineParams,
)
from stripe.params.issuing._authorization_expire_params import (
    AuthorizationExpireParams as AuthorizationExpireParams,
)
from stripe.params.issuing._authorization_finalize_amount_params import (
    AuthorizationFinalizeAmountParams as AuthorizationFinalizeAmountParams,
    AuthorizationFinalizeAmountParamsFleet as AuthorizationFinalizeAmountParamsFleet,
    AuthorizationFinalizeAmountParamsFleetCardholderPromptData as AuthorizationFinalizeAmountParamsFleetCardholderPromptData,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdown as AuthorizationFinalizeAmountParamsFleetReportedBreakdown,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownFuel as AuthorizationFinalizeAmountParamsFleetReportedBreakdownFuel,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownNonFuel as AuthorizationFinalizeAmountParamsFleetReportedBreakdownNonFuel,
    AuthorizationFinalizeAmountParamsFleetReportedBreakdownTax as AuthorizationFinalizeAmountParamsFleetReportedBreakdownTax,
    AuthorizationFinalizeAmountParamsFuel as AuthorizationFinalizeAmountParamsFuel,
)
from stripe.params.issuing._authorization_increment_params import (
    AuthorizationIncrementParams as AuthorizationIncrementParams,
)
from stripe.params.issuing._authorization_list_params import (
    AuthorizationListParams as AuthorizationListParams,
    AuthorizationListParamsCreated as AuthorizationListParamsCreated,
)
from stripe.params.issuing._authorization_modify_params import (
    AuthorizationModifyParams as AuthorizationModifyParams,
)
from stripe.params.issuing._authorization_respond_params import (
    AuthorizationRespondParams as AuthorizationRespondParams,
)
from stripe.params.issuing._authorization_retrieve_params import (
    AuthorizationRetrieveParams as AuthorizationRetrieveParams,
)
from stripe.params.issuing._authorization_reverse_params import (
    AuthorizationReverseParams as AuthorizationReverseParams,
)
from stripe.params.issuing._authorization_update_params import (
    AuthorizationUpdateParams as AuthorizationUpdateParams,
)
from stripe.params.issuing._card_create_params import (
    CardCreateParams as CardCreateParams,
    CardCreateParamsPin as CardCreateParamsPin,
    CardCreateParamsShipping as CardCreateParamsShipping,
    CardCreateParamsShippingAddress as CardCreateParamsShippingAddress,
    CardCreateParamsShippingAddressValidation as CardCreateParamsShippingAddressValidation,
    CardCreateParamsShippingCustoms as CardCreateParamsShippingCustoms,
    CardCreateParamsSpendingControls as CardCreateParamsSpendingControls,
    CardCreateParamsSpendingControlsSpendingLimit as CardCreateParamsSpendingControlsSpendingLimit,
)
from stripe.params.issuing._card_deliver_card_params import (
    CardDeliverCardParams as CardDeliverCardParams,
)
from stripe.params.issuing._card_fail_card_params import (
    CardFailCardParams as CardFailCardParams,
)
from stripe.params.issuing._card_list_params import (
    CardListParams as CardListParams,
    CardListParamsCreated as CardListParamsCreated,
)
from stripe.params.issuing._card_modify_params import (
    CardModifyParams as CardModifyParams,
    CardModifyParamsPin as CardModifyParamsPin,
    CardModifyParamsShipping as CardModifyParamsShipping,
    CardModifyParamsShippingAddress as CardModifyParamsShippingAddress,
    CardModifyParamsShippingAddressValidation as CardModifyParamsShippingAddressValidation,
    CardModifyParamsShippingCustoms as CardModifyParamsShippingCustoms,
    CardModifyParamsSpendingControls as CardModifyParamsSpendingControls,
    CardModifyParamsSpendingControlsSpendingLimit as CardModifyParamsSpendingControlsSpendingLimit,
)
from stripe.params.issuing._card_retrieve_params import (
    CardRetrieveParams as CardRetrieveParams,
)
from stripe.params.issuing._card_return_card_params import (
    CardReturnCardParams as CardReturnCardParams,
)
from stripe.params.issuing._card_ship_card_params import (
    CardShipCardParams as CardShipCardParams,
)
from stripe.params.issuing._card_submit_card_params import (
    CardSubmitCardParams as CardSubmitCardParams,
)
from stripe.params.issuing._card_update_params import (
    CardUpdateParams as CardUpdateParams,
    CardUpdateParamsPin as CardUpdateParamsPin,
    CardUpdateParamsShipping as CardUpdateParamsShipping,
    CardUpdateParamsShippingAddress as CardUpdateParamsShippingAddress,
    CardUpdateParamsShippingAddressValidation as CardUpdateParamsShippingAddressValidation,
    CardUpdateParamsShippingCustoms as CardUpdateParamsShippingCustoms,
    CardUpdateParamsSpendingControls as CardUpdateParamsSpendingControls,
    CardUpdateParamsSpendingControlsSpendingLimit as CardUpdateParamsSpendingControlsSpendingLimit,
)
from stripe.params.issuing._cardholder_create_params import (
    CardholderCreateParams as CardholderCreateParams,
    CardholderCreateParamsBilling as CardholderCreateParamsBilling,
    CardholderCreateParamsBillingAddress as CardholderCreateParamsBillingAddress,
    CardholderCreateParamsCompany as CardholderCreateParamsCompany,
    CardholderCreateParamsIndividual as CardholderCreateParamsIndividual,
    CardholderCreateParamsIndividualCardIssuing as CardholderCreateParamsIndividualCardIssuing,
    CardholderCreateParamsIndividualCardIssuingUserTermsAcceptance as CardholderCreateParamsIndividualCardIssuingUserTermsAcceptance,
    CardholderCreateParamsIndividualDob as CardholderCreateParamsIndividualDob,
    CardholderCreateParamsIndividualVerification as CardholderCreateParamsIndividualVerification,
    CardholderCreateParamsIndividualVerificationDocument as CardholderCreateParamsIndividualVerificationDocument,
    CardholderCreateParamsSpendingControls as CardholderCreateParamsSpendingControls,
    CardholderCreateParamsSpendingControlsSpendingLimit as CardholderCreateParamsSpendingControlsSpendingLimit,
)
from stripe.params.issuing._cardholder_list_params import (
    CardholderListParams as CardholderListParams,
    CardholderListParamsCreated as CardholderListParamsCreated,
)
from stripe.params.issuing._cardholder_modify_params import (
    CardholderModifyParams as CardholderModifyParams,
    CardholderModifyParamsBilling as CardholderModifyParamsBilling,
    CardholderModifyParamsBillingAddress as CardholderModifyParamsBillingAddress,
    CardholderModifyParamsCompany as CardholderModifyParamsCompany,
    CardholderModifyParamsIndividual as CardholderModifyParamsIndividual,
    CardholderModifyParamsIndividualCardIssuing as CardholderModifyParamsIndividualCardIssuing,
    CardholderModifyParamsIndividualCardIssuingUserTermsAcceptance as CardholderModifyParamsIndividualCardIssuingUserTermsAcceptance,
    CardholderModifyParamsIndividualDob as CardholderModifyParamsIndividualDob,
    CardholderModifyParamsIndividualVerification as CardholderModifyParamsIndividualVerification,
    CardholderModifyParamsIndividualVerificationDocument as CardholderModifyParamsIndividualVerificationDocument,
    CardholderModifyParamsSpendingControls as CardholderModifyParamsSpendingControls,
    CardholderModifyParamsSpendingControlsSpendingLimit as CardholderModifyParamsSpendingControlsSpendingLimit,
)
from stripe.params.issuing._cardholder_retrieve_params import (
    CardholderRetrieveParams as CardholderRetrieveParams,
)
from stripe.params.issuing._cardholder_update_params import (
    CardholderUpdateParams as CardholderUpdateParams,
    CardholderUpdateParamsBilling as CardholderUpdateParamsBilling,
    CardholderUpdateParamsBillingAddress as CardholderUpdateParamsBillingAddress,
    CardholderUpdateParamsCompany as CardholderUpdateParamsCompany,
    CardholderUpdateParamsIndividual as CardholderUpdateParamsIndividual,
    CardholderUpdateParamsIndividualCardIssuing as CardholderUpdateParamsIndividualCardIssuing,
    CardholderUpdateParamsIndividualCardIssuingUserTermsAcceptance as CardholderUpdateParamsIndividualCardIssuingUserTermsAcceptance,
    CardholderUpdateParamsIndividualDob as CardholderUpdateParamsIndividualDob,
    CardholderUpdateParamsIndividualVerification as CardholderUpdateParamsIndividualVerification,
    CardholderUpdateParamsIndividualVerificationDocument as CardholderUpdateParamsIndividualVerificationDocument,
    CardholderUpdateParamsSpendingControls as CardholderUpdateParamsSpendingControls,
    CardholderUpdateParamsSpendingControlsSpendingLimit as CardholderUpdateParamsSpendingControlsSpendingLimit,
)
from stripe.params.issuing._credit_underwriting_record_correct_params import (
    CreditUnderwritingRecordCorrectParams as CreditUnderwritingRecordCorrectParams,
    CreditUnderwritingRecordCorrectParamsApplication as CreditUnderwritingRecordCorrectParamsApplication,
    CreditUnderwritingRecordCorrectParamsCreditUser as CreditUnderwritingRecordCorrectParamsCreditUser,
    CreditUnderwritingRecordCorrectParamsDecision as CreditUnderwritingRecordCorrectParamsDecision,
    CreditUnderwritingRecordCorrectParamsDecisionApplicationRejected as CreditUnderwritingRecordCorrectParamsDecisionApplicationRejected,
    CreditUnderwritingRecordCorrectParamsDecisionCreditLimitApproved as CreditUnderwritingRecordCorrectParamsDecisionCreditLimitApproved,
    CreditUnderwritingRecordCorrectParamsDecisionCreditLimitDecreased as CreditUnderwritingRecordCorrectParamsDecisionCreditLimitDecreased,
    CreditUnderwritingRecordCorrectParamsDecisionCreditLineClosed as CreditUnderwritingRecordCorrectParamsDecisionCreditLineClosed,
    CreditUnderwritingRecordCorrectParamsUnderwritingException as CreditUnderwritingRecordCorrectParamsUnderwritingException,
)
from stripe.params.issuing._credit_underwriting_record_create_from_application_params import (
    CreditUnderwritingRecordCreateFromApplicationParams as CreditUnderwritingRecordCreateFromApplicationParams,
    CreditUnderwritingRecordCreateFromApplicationParamsApplication as CreditUnderwritingRecordCreateFromApplicationParamsApplication,
    CreditUnderwritingRecordCreateFromApplicationParamsCreditUser as CreditUnderwritingRecordCreateFromApplicationParamsCreditUser,
)
from stripe.params.issuing._credit_underwriting_record_create_from_proactive_review_params import (
    CreditUnderwritingRecordCreateFromProactiveReviewParams as CreditUnderwritingRecordCreateFromProactiveReviewParams,
    CreditUnderwritingRecordCreateFromProactiveReviewParamsCreditUser as CreditUnderwritingRecordCreateFromProactiveReviewParamsCreditUser,
    CreditUnderwritingRecordCreateFromProactiveReviewParamsDecision as CreditUnderwritingRecordCreateFromProactiveReviewParamsDecision,
    CreditUnderwritingRecordCreateFromProactiveReviewParamsDecisionCreditLimitApproved as CreditUnderwritingRecordCreateFromProactiveReviewParamsDecisionCreditLimitApproved,
    CreditUnderwritingRecordCreateFromProactiveReviewParamsDecisionCreditLimitDecreased as CreditUnderwritingRecordCreateFromProactiveReviewParamsDecisionCreditLimitDecreased,
    CreditUnderwritingRecordCreateFromProactiveReviewParamsDecisionCreditLineClosed as CreditUnderwritingRecordCreateFromProactiveReviewParamsDecisionCreditLineClosed,
    CreditUnderwritingRecordCreateFromProactiveReviewParamsUnderwritingException as CreditUnderwritingRecordCreateFromProactiveReviewParamsUnderwritingException,
)
from stripe.params.issuing._credit_underwriting_record_list_params import (
    CreditUnderwritingRecordListParams as CreditUnderwritingRecordListParams,
)
from stripe.params.issuing._credit_underwriting_record_report_decision_params import (
    CreditUnderwritingRecordReportDecisionParams as CreditUnderwritingRecordReportDecisionParams,
    CreditUnderwritingRecordReportDecisionParamsDecision as CreditUnderwritingRecordReportDecisionParamsDecision,
    CreditUnderwritingRecordReportDecisionParamsDecisionApplicationRejected as CreditUnderwritingRecordReportDecisionParamsDecisionApplicationRejected,
    CreditUnderwritingRecordReportDecisionParamsDecisionCreditLimitApproved as CreditUnderwritingRecordReportDecisionParamsDecisionCreditLimitApproved,
    CreditUnderwritingRecordReportDecisionParamsUnderwritingException as CreditUnderwritingRecordReportDecisionParamsUnderwritingException,
)
from stripe.params.issuing._credit_underwriting_record_retrieve_params import (
    CreditUnderwritingRecordRetrieveParams as CreditUnderwritingRecordRetrieveParams,
)
from stripe.params.issuing._dispute_create_params import (
    DisputeCreateParams as DisputeCreateParams,
    DisputeCreateParamsEvidence as DisputeCreateParamsEvidence,
    DisputeCreateParamsEvidenceCanceled as DisputeCreateParamsEvidenceCanceled,
    DisputeCreateParamsEvidenceDuplicate as DisputeCreateParamsEvidenceDuplicate,
    DisputeCreateParamsEvidenceFraudulent as DisputeCreateParamsEvidenceFraudulent,
    DisputeCreateParamsEvidenceMerchandiseNotAsDescribed as DisputeCreateParamsEvidenceMerchandiseNotAsDescribed,
    DisputeCreateParamsEvidenceNoValidAuthorization as DisputeCreateParamsEvidenceNoValidAuthorization,
    DisputeCreateParamsEvidenceNotReceived as DisputeCreateParamsEvidenceNotReceived,
    DisputeCreateParamsEvidenceOther as DisputeCreateParamsEvidenceOther,
    DisputeCreateParamsEvidenceServiceNotAsDescribed as DisputeCreateParamsEvidenceServiceNotAsDescribed,
    DisputeCreateParamsTreasury as DisputeCreateParamsTreasury,
)
from stripe.params.issuing._dispute_list_params import (
    DisputeListParams as DisputeListParams,
    DisputeListParamsCreated as DisputeListParamsCreated,
)
from stripe.params.issuing._dispute_modify_params import (
    DisputeModifyParams as DisputeModifyParams,
    DisputeModifyParamsEvidence as DisputeModifyParamsEvidence,
    DisputeModifyParamsEvidenceCanceled as DisputeModifyParamsEvidenceCanceled,
    DisputeModifyParamsEvidenceDuplicate as DisputeModifyParamsEvidenceDuplicate,
    DisputeModifyParamsEvidenceFraudulent as DisputeModifyParamsEvidenceFraudulent,
    DisputeModifyParamsEvidenceMerchandiseNotAsDescribed as DisputeModifyParamsEvidenceMerchandiseNotAsDescribed,
    DisputeModifyParamsEvidenceNoValidAuthorization as DisputeModifyParamsEvidenceNoValidAuthorization,
    DisputeModifyParamsEvidenceNotReceived as DisputeModifyParamsEvidenceNotReceived,
    DisputeModifyParamsEvidenceOther as DisputeModifyParamsEvidenceOther,
    DisputeModifyParamsEvidenceServiceNotAsDescribed as DisputeModifyParamsEvidenceServiceNotAsDescribed,
)
from stripe.params.issuing._dispute_retrieve_params import (
    DisputeRetrieveParams as DisputeRetrieveParams,
)
from stripe.params.issuing._dispute_settlement_detail_list_params import (
    DisputeSettlementDetailListParams as DisputeSettlementDetailListParams,
)
from stripe.params.issuing._dispute_settlement_detail_retrieve_params import (
    DisputeSettlementDetailRetrieveParams as DisputeSettlementDetailRetrieveParams,
)
from stripe.params.issuing._dispute_submit_params import (
    DisputeSubmitParams as DisputeSubmitParams,
)
from stripe.params.issuing._dispute_update_params import (
    DisputeUpdateParams as DisputeUpdateParams,
    DisputeUpdateParamsEvidence as DisputeUpdateParamsEvidence,
    DisputeUpdateParamsEvidenceCanceled as DisputeUpdateParamsEvidenceCanceled,
    DisputeUpdateParamsEvidenceDuplicate as DisputeUpdateParamsEvidenceDuplicate,
    DisputeUpdateParamsEvidenceFraudulent as DisputeUpdateParamsEvidenceFraudulent,
    DisputeUpdateParamsEvidenceMerchandiseNotAsDescribed as DisputeUpdateParamsEvidenceMerchandiseNotAsDescribed,
    DisputeUpdateParamsEvidenceNoValidAuthorization as DisputeUpdateParamsEvidenceNoValidAuthorization,
    DisputeUpdateParamsEvidenceNotReceived as DisputeUpdateParamsEvidenceNotReceived,
    DisputeUpdateParamsEvidenceOther as DisputeUpdateParamsEvidenceOther,
    DisputeUpdateParamsEvidenceServiceNotAsDescribed as DisputeUpdateParamsEvidenceServiceNotAsDescribed,
)
from stripe.params.issuing._fraud_liability_debit_list_params import (
    FraudLiabilityDebitListParams as FraudLiabilityDebitListParams,
    FraudLiabilityDebitListParamsCreated as FraudLiabilityDebitListParamsCreated,
)
from stripe.params.issuing._fraud_liability_debit_retrieve_params import (
    FraudLiabilityDebitRetrieveParams as FraudLiabilityDebitRetrieveParams,
)
from stripe.params.issuing._personalization_design_activate_params import (
    PersonalizationDesignActivateParams as PersonalizationDesignActivateParams,
)
from stripe.params.issuing._personalization_design_create_params import (
    PersonalizationDesignCreateParams as PersonalizationDesignCreateParams,
    PersonalizationDesignCreateParamsCarrierText as PersonalizationDesignCreateParamsCarrierText,
    PersonalizationDesignCreateParamsPreferences as PersonalizationDesignCreateParamsPreferences,
)
from stripe.params.issuing._personalization_design_deactivate_params import (
    PersonalizationDesignDeactivateParams as PersonalizationDesignDeactivateParams,
)
from stripe.params.issuing._personalization_design_list_params import (
    PersonalizationDesignListParams as PersonalizationDesignListParams,
    PersonalizationDesignListParamsPreferences as PersonalizationDesignListParamsPreferences,
)
from stripe.params.issuing._personalization_design_modify_params import (
    PersonalizationDesignModifyParams as PersonalizationDesignModifyParams,
    PersonalizationDesignModifyParamsCarrierText as PersonalizationDesignModifyParamsCarrierText,
    PersonalizationDesignModifyParamsPreferences as PersonalizationDesignModifyParamsPreferences,
)
from stripe.params.issuing._personalization_design_reject_params import (
    PersonalizationDesignRejectParams as PersonalizationDesignRejectParams,
    PersonalizationDesignRejectParamsRejectionReasons as PersonalizationDesignRejectParamsRejectionReasons,
)
from stripe.params.issuing._personalization_design_retrieve_params import (
    PersonalizationDesignRetrieveParams as PersonalizationDesignRetrieveParams,
)
from stripe.params.issuing._personalization_design_update_params import (
    PersonalizationDesignUpdateParams as PersonalizationDesignUpdateParams,
    PersonalizationDesignUpdateParamsCarrierText as PersonalizationDesignUpdateParamsCarrierText,
    PersonalizationDesignUpdateParamsPreferences as PersonalizationDesignUpdateParamsPreferences,
)
from stripe.params.issuing._physical_bundle_list_params import (
    PhysicalBundleListParams as PhysicalBundleListParams,
)
from stripe.params.issuing._physical_bundle_retrieve_params import (
    PhysicalBundleRetrieveParams as PhysicalBundleRetrieveParams,
)
from stripe.params.issuing._token_list_params import (
    TokenListParams as TokenListParams,
    TokenListParamsCreated as TokenListParamsCreated,
)
from stripe.params.issuing._token_modify_params import (
    TokenModifyParams as TokenModifyParams,
)
from stripe.params.issuing._token_retrieve_params import (
    TokenRetrieveParams as TokenRetrieveParams,
)
from stripe.params.issuing._token_update_params import (
    TokenUpdateParams as TokenUpdateParams,
)
from stripe.params.issuing._transaction_create_force_capture_params import (
    TransactionCreateForceCaptureParams as TransactionCreateForceCaptureParams,
    TransactionCreateForceCaptureParamsMerchantData as TransactionCreateForceCaptureParamsMerchantData,
    TransactionCreateForceCaptureParamsPurchaseDetails as TransactionCreateForceCaptureParamsPurchaseDetails,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleet as TransactionCreateForceCaptureParamsPurchaseDetailsFleet,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetCardholderPromptData as TransactionCreateForceCaptureParamsPurchaseDetailsFleetCardholderPromptData,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdown as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdown,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownTax as TransactionCreateForceCaptureParamsPurchaseDetailsFleetReportedBreakdownTax,
    TransactionCreateForceCaptureParamsPurchaseDetailsFlight as TransactionCreateForceCaptureParamsPurchaseDetailsFlight,
    TransactionCreateForceCaptureParamsPurchaseDetailsFlightSegment as TransactionCreateForceCaptureParamsPurchaseDetailsFlightSegment,
    TransactionCreateForceCaptureParamsPurchaseDetailsFuel as TransactionCreateForceCaptureParamsPurchaseDetailsFuel,
    TransactionCreateForceCaptureParamsPurchaseDetailsLodging as TransactionCreateForceCaptureParamsPurchaseDetailsLodging,
    TransactionCreateForceCaptureParamsPurchaseDetailsReceipt as TransactionCreateForceCaptureParamsPurchaseDetailsReceipt,
)
from stripe.params.issuing._transaction_create_unlinked_refund_params import (
    TransactionCreateUnlinkedRefundParams as TransactionCreateUnlinkedRefundParams,
    TransactionCreateUnlinkedRefundParamsMerchantData as TransactionCreateUnlinkedRefundParamsMerchantData,
    TransactionCreateUnlinkedRefundParamsPurchaseDetails as TransactionCreateUnlinkedRefundParamsPurchaseDetails,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleet as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleet,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetCardholderPromptData as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetCardholderPromptData,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdown as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdown,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownNonFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownNonFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownTax as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFleetReportedBreakdownTax,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlight as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlight,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlightSegment as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFlightSegment,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsFuel as TransactionCreateUnlinkedRefundParamsPurchaseDetailsFuel,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsLodging as TransactionCreateUnlinkedRefundParamsPurchaseDetailsLodging,
    TransactionCreateUnlinkedRefundParamsPurchaseDetailsReceipt as TransactionCreateUnlinkedRefundParamsPurchaseDetailsReceipt,
)
from stripe.params.issuing._transaction_list_params import (
    TransactionListParams as TransactionListParams,
    TransactionListParamsCreated as TransactionListParamsCreated,
)
from stripe.params.issuing._transaction_modify_params import (
    TransactionModifyParams as TransactionModifyParams,
)
from stripe.params.issuing._transaction_refund_params import (
    TransactionRefundParams as TransactionRefundParams,
)
from stripe.params.issuing._transaction_retrieve_params import (
    TransactionRetrieveParams as TransactionRetrieveParams,
)
from stripe.params.issuing._transaction_update_params import (
    TransactionUpdateParams as TransactionUpdateParams,
)



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.v2.core.accounts._person_create_params import (
    PersonCreateParams as PersonCreateParams,
    PersonCreateParamsAdditionalAddress as PersonCreateParamsAdditionalAddress,
    PersonCreateParamsAdditionalName as PersonCreateParamsAdditionalName,
    PersonCreateParamsAdditionalTermsOfService as PersonCreateParamsAdditionalTermsOfService,
    PersonCreateParamsAdditionalTermsOfServiceAccount as PersonCreateParamsAdditionalTermsOfServiceAccount,
    PersonCreateParamsAddress as PersonCreateParamsAddress,
    PersonCreateParamsDateOfBirth as PersonCreateParamsDateOfBirth,
    PersonCreateParamsDocuments as PersonCreateParamsDocuments,
    PersonCreateParamsDocumentsCompanyAuthorization as PersonCreateParamsDocumentsCompanyAuthorization,
    PersonCreateParamsDocumentsPassport as PersonCreateParamsDocumentsPassport,
    PersonCreateParamsDocumentsPrimaryVerification as PersonCreateParamsDocumentsPrimaryVerification,
    PersonCreateParamsDocumentsPrimaryVerificationFrontBack as PersonCreateParamsDocumentsPrimaryVerificationFrontBack,
    PersonCreateParamsDocumentsSecondaryVerification as PersonCreateParamsDocumentsSecondaryVerification,
    PersonCreateParamsDocumentsSecondaryVerificationFrontBack as PersonCreateParamsDocumentsSecondaryVerificationFrontBack,
    PersonCreateParamsDocumentsVisa as PersonCreateParamsDocumentsVisa,
    PersonCreateParamsIdNumber as PersonCreateParamsIdNumber,
    PersonCreateParamsRelationship as PersonCreateParamsRelationship,
    PersonCreateParamsScriptAddresses as PersonCreateParamsScriptAddresses,
    PersonCreateParamsScriptAddressesKana as PersonCreateParamsScriptAddressesKana,
    PersonCreateParamsScriptAddressesKanji as PersonCreateParamsScriptAddressesKanji,
    PersonCreateParamsScriptNames as PersonCreateParamsScriptNames,
    PersonCreateParamsScriptNamesKana as PersonCreateParamsScriptNamesKana,
    PersonCreateParamsScriptNamesKanji as PersonCreateParamsScriptNamesKanji,
)
from stripe.params.v2.core.accounts._person_delete_params import (
    PersonDeleteParams as PersonDeleteParams,
)
from stripe.params.v2.core.accounts._person_list_params import (
    PersonListParams as PersonListParams,
)
from stripe.params.v2.core.accounts._person_retrieve_params import (
    PersonRetrieveParams as PersonRetrieveParams,
)
from stripe.params.v2.core.accounts._person_update_params import (
    PersonUpdateParams as PersonUpdateParams,
    PersonUpdateParamsAdditionalAddress as PersonUpdateParamsAdditionalAddress,
    PersonUpdateParamsAdditionalName as PersonUpdateParamsAdditionalName,
    PersonUpdateParamsAdditionalTermsOfService as PersonUpdateParamsAdditionalTermsOfService,
    PersonUpdateParamsAdditionalTermsOfServiceAccount as PersonUpdateParamsAdditionalTermsOfServiceAccount,
    PersonUpdateParamsAddress as PersonUpdateParamsAddress,
    PersonUpdateParamsDateOfBirth as PersonUpdateParamsDateOfBirth,
    PersonUpdateParamsDocuments as PersonUpdateParamsDocuments,
    PersonUpdateParamsDocumentsCompanyAuthorization as PersonUpdateParamsDocumentsCompanyAuthorization,
    PersonUpdateParamsDocumentsPassport as PersonUpdateParamsDocumentsPassport,
    PersonUpdateParamsDocumentsPrimaryVerification as PersonUpdateParamsDocumentsPrimaryVerification,
    PersonUpdateParamsDocumentsPrimaryVerificationFrontBack as PersonUpdateParamsDocumentsPrimaryVerificationFrontBack,
    PersonUpdateParamsDocumentsSecondaryVerification as PersonUpdateParamsDocumentsSecondaryVerification,
    PersonUpdateParamsDocumentsSecondaryVerificationFrontBack as PersonUpdateParamsDocumentsSecondaryVerificationFrontBack,
    PersonUpdateParamsDocumentsVisa as PersonUpdateParamsDocumentsVisa,
    PersonUpdateParamsIdNumber as PersonUpdateParamsIdNumber,
    PersonUpdateParamsRelationship as PersonUpdateParamsRelationship,
    PersonUpdateParamsScriptAddresses as PersonUpdateParamsScriptAddresses,
    PersonUpdateParamsScriptAddressesKana as PersonUpdateParamsScriptAddressesKana,
    PersonUpdateParamsScriptAddressesKanji as PersonUpdateParamsScriptAddressesKanji,
    PersonUpdateParamsScriptNames as PersonUpdateParamsScriptNames,
    PersonUpdateParamsScriptNamesKana as PersonUpdateParamsScriptNamesKana,
    PersonUpdateParamsScriptNamesKanji as PersonUpdateParamsScriptNamesKanji,
)
